@@ -13,14 +13,13 @@
 #
 # Copyright Buildbot Team Members
 
-
-from twisted.python import log
 from twisted.internet import defer
+from twisted.python import log
 
-from buildbot.pbutil import NewCredPerspective
-from buildbot.changes import base
-from buildbot.util import epoch2datetime
 from buildbot import config
+from buildbot.changes import base
+from buildbot.pbutil import NewCredPerspective
+
 
 class ChangePerspective(NewCredPerspective):
 
@@ -30,6 +29,7 @@ class ChangePerspective(NewCredPerspective):
 
     def attached(self, mind):
         return self
+
     def detached(self, mind):
         pass
 
@@ -44,23 +44,19 @@ class ChangePerspective(NewCredPerspective):
             changedict['project'] = ''
         if 'files' not in changedict or not changedict['files']:
             changedict['files'] = []
+        if 'committer' in changedict and not changedict['committer']:
+            changedict['committer'] = None
 
         # rename arguments to new names.  Note that the client still uses the
         # "old" names (who, when, and isdir), as they are not deprecated yet,
         # although the master will accept the new names (author,
-        # when_timestamp, and is_dir).  After a few revisions have passed, we
+        # when_timestamp).  After a few revisions have passed, we
         # can switch the client to use the new names.
-        if 'isdir' in changedict:
-            changedict['is_dir'] = changedict['isdir']
-            del changedict['isdir']
         if 'who' in changedict:
             changedict['author'] = changedict['who']
             del changedict['who']
         if 'when' in changedict:
-            when = None
-            if changedict['when'] is not None:
-                when = epoch2datetime(changedict['when'])
-            changedict['when_timestamp'] = when
+            changedict['when_timestamp'] = changedict['when']
             del changedict['when']
 
         # turn any bytestring keys into unicode, assuming utf8 but just
@@ -68,11 +64,11 @@ class ChangePerspective(NewCredPerspective):
         # in the first place, but older clients do not, so this fallback is
         # useful.
         for key in changedict:
-            if type(changedict[key]) == str:
+            if isinstance(changedict[key], bytes):
                 changedict[key] = changedict[key].decode('utf8', 'replace')
         changedict['files'] = list(changedict['files'])
         for i, file in enumerate(changedict.get('files', [])):
-            if type(file) == str:
+            if isinstance(file, bytes):
                 changedict['files'][i] = file.decode('utf8', 'replace')
 
         files = []
@@ -88,21 +84,31 @@ class ChangePerspective(NewCredPerspective):
         if not files:
             log.msg("No files listed in change... bit strange, but not fatal.")
 
-        if changedict.has_key('links'):
-            log.msg("Found links: "+repr(changedict['links']))
+        if "links" in changedict:
+            log.msg("Found links: " + repr(changedict['links']))
             del changedict['links']
 
-        d = self.master.addChange(**changedict)
-        # since this is a remote method, we can't return a Change instance, so
-        # this just sets the return value to None:
-        d.addCallback(lambda _ : None)
+        d = self.master.data.updates.addChange(**changedict)
+
+        # set the return value to None, so we don't get users depending on
+        # getting a changeid
+        d.addCallback(lambda _: None)
         return d
 
-class PBChangeSource(config.ReconfigurableServiceMixin, base.ChangeSource):
-    compare_attrs = ["user", "passwd", "port", "prefix", "port"]
+
+class PBChangeSource(base.ChangeSource):
+    compare_attrs = ("user", "passwd", "port", "prefix", "port")
 
     def __init__(self, user="change", passwd="changepw", port=None,
-            prefix=None):
+                 prefix=None, name=None):
+
+        if name is None:
+            if prefix:
+                name = f"PBChangeSource:{prefix}:{port}"
+            else:
+                name = f"PBChangeSource:{port}"
+
+        super().__init__(name=name)
 
         self.user = user
         self.passwd = passwd
@@ -115,37 +121,46 @@ class PBChangeSource(config.ReconfigurableServiceMixin, base.ChangeSource):
         portname = self.registered_port
         d = "PBChangeSource listener on " + str(portname)
         if self.prefix is not None:
-            d += " (prefix '%s')" % self.prefix
+            d += f" (prefix '{self.prefix}')"
         return d
 
-    @defer.inlineCallbacks
-    def reconfigService(self, new_config):
-        # calculate the new port
+    def _calculatePort(self, cfg):
+        # calculate the new port, defaulting to the worker's PB port if
+        # none was specified
         port = self.port
         if port is None:
-            port = new_config.slavePortnum
+            port = cfg.protocols.get('pb', {}).get('port')
+        return port
+
+    @defer.inlineCallbacks
+    def reconfigServiceWithBuildbotConfig(self, new_config):
+        port = self._calculatePort(new_config)
+        if not port:
+            config.error("No port specified for PBChangeSource, and no "
+                         "worker port configured")
 
         # and, if it's changed, re-register
-        if port != self.registered_port:
+        if port != self.registered_port and self.isActive():
             yield self._unregister()
-            self._register(port)
+            yield self._register(port)
 
-        yield config.ReconfigurableServiceMixin.reconfigService(
-                self, new_config)
+        yield super().reconfigServiceWithBuildbotConfig(new_config)
 
-    def stopService(self):
-        d = defer.maybeDeferred(base.ChangeSource.stopService, self)
-        d.addCallback(lambda _ : self._unregister())
-        return d
+    @defer.inlineCallbacks
+    def activate(self):
+        port = self._calculatePort(self.master.config)
+        yield self._register(port)
 
+    def deactivate(self):
+        return self._unregister()
+
+    @defer.inlineCallbacks
     def _register(self, port):
         if not port:
-            log.msg("PBChangeSource has no port to listen on")
             return
         self.registered_port = port
-        self.registration = self.master.pbmanager.register(
-                port, self.user, self.passwd,
-                self.getPerspective)
+        self.registration = yield self.master.pbmanager.register(port, self.user, self.passwd,
+                                                                 self.getPerspective)
 
     def _unregister(self):
         self.registered_port = None
@@ -153,8 +168,7 @@ class PBChangeSource(config.ReconfigurableServiceMixin, base.ChangeSource):
             reg = self.registration
             self.registration = None
             return reg.unregister()
-        else:
-            return defer.succeed(None)
+        return defer.succeed(None)
 
     def getPerspective(self, mind, username):
         assert username == self.user
