@@ -17,7 +17,7 @@ do
     fi
     . $VE/bin/activate
     pip install -U pip
-    pip install  mock requests flask
+    pip install requests flask
     pip install dist/buildbot-[0-9]*.$suffix
     pip install dist/buildbot?pkg*.$suffix
     pip install dist/*.$suffix
