@@ -22,7 +22,7 @@ from buildbot.data import types
 
 class BuilderEndpoint(base.BuildNestingMixin, base.Endpoint):
 
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /builders/n:builderid
         /builders/i:buildername
@@ -41,32 +41,52 @@ class BuilderEndpoint(base.BuildNestingMixin, base.Endpoint):
         if 'masterid' in kwargs:
             if kwargs['masterid'] not in bdict['masterids']:
                 return None
-        return dict(builderid=builderid,
-                    name=bdict['name'],
-                    masterids=bdict['masterids'],
-                    description=bdict['description'],
-                    tags=bdict['tags'])
+        return {
+            "builderid": builderid,
+            "name": bdict['name'],
+            "masterids": bdict['masterids'],
+            "description": bdict['description'],
+            "description_format": bdict["description_format"],
+            "description_html": bdict["description_html"],
+            "projectid": bdict['projectid'],
+            "tags": bdict['tags']
+        }
 
 
 class BuildersEndpoint(base.Endpoint):
 
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     rootLinkName = 'builders'
     pathPatterns = """
         /builders
         /masters/n:masterid/builders
+        /projects/n:projectid/builders
     """
 
     @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
         bdicts = yield self.master.db.builders.getBuilders(
-            masterid=kwargs.get('masterid', None))
-        return [dict(builderid=bd['id'],
-                     name=bd['name'],
-                     masterids=bd['masterids'],
-                     description=bd['description'],
-                     tags=bd['tags'])
-               for bd in bdicts]
+            masterid=kwargs.get('masterid', None),
+            projectid=kwargs.get('projectid', None)
+        )
+        return [
+            {
+                "builderid": bd['id'],
+                "name": bd['name'],
+                "masterids": bd['masterids'],
+                "description": bd['description'],
+                "description_format": bd['description_format'],
+                "description_html": bd['description_html'],
+                "projectid": bd['projectid'],
+                "tags": bd['tags']
+            }
+            for bd in bdicts
+        ]
+
+    def get_kwargs_from_graphql(self, parent, resolve_info, args):
+        if parent is not None:
+            return {'masterid': parent['masterid']}
+        return {}
 
 
 class Builder(base.ResourceType):
@@ -74,21 +94,22 @@ class Builder(base.ResourceType):
     name = "builder"
     plural = "builders"
     endpoints = [BuilderEndpoint, BuildersEndpoint]
-    keyFields = ['builderid']
+    keyField = 'builderid'
     eventPathPatterns = """
         /builders/:builderid
     """
+    subresources = ["Build", "Forcescheduler", "Scheduler", "Buildrequest"]
 
     class EntityType(types.Entity):
         builderid = types.Integer()
         name = types.Identifier(70)
         masterids = types.List(of=types.Integer())
         description = types.NoneOk(types.String())
+        description_format = types.NoneOk(types.String())
+        description_html = types.NoneOk(types.String())
+        projectid = types.NoneOk(types.Integer())
         tags = types.List(of=types.String())
-    entityType = EntityType(name)
-
-    def __init__(self, master):
-        base.ResourceType.__init__(self, master)
+    entityType = EntityType(name, 'Builder')
 
     @defer.inlineCallbacks
     def generateEvent(self, _id, event):
@@ -101,8 +122,11 @@ class Builder(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def updateBuilderInfo(self, builderid, description, tags):
-        ret = yield self.master.db.builders.updateBuilderInfo(builderid, description, tags)
+    def updateBuilderInfo(self, builderid, description, description_format, description_html,
+                          projectid, tags):
+        ret = yield self.master.db.builders.updateBuilderInfo(
+            builderid, description, description_format, description_html, projectid, tags
+        )
         yield self.generateEvent(builderid, "update")
         return ret
 
@@ -121,9 +145,11 @@ class Builder(base.ResourceType):
                 builderid = bldr['id']
                 yield self.master.db.builders.removeBuilderMaster(
                     masterid=masterid, builderid=builderid)
-                self.master.mq.produce(('builders', str(builderid), 'stopped'),
-                                       dict(builderid=builderid, masterid=masterid,
-                                            name=bldr['name']))
+                self.master.mq.produce(('builders', str(builderid), 'stopped'), {
+                    "builderid": builderid,
+                    "masterid": masterid,
+                    "name": bldr['name']
+                })
             else:
                 builderNames_set.remove(bldr['name'])
 
@@ -133,7 +159,7 @@ class Builder(base.ResourceType):
             yield self.master.db.builders.addBuilderMaster(
                 masterid=masterid, builderid=builderid)
             self.master.mq.produce(('builders', str(builderid), 'started'),
-                                   dict(builderid=builderid, masterid=masterid, name=name))
+                                   {"builderid": builderid, "masterid": masterid, "name": name})
 
     # returns a Deferred that returns None
     def _masterDeactivated(self, masterid):
