@@ -56,6 +56,7 @@ class DataConnector(service.AsyncService):
         'buildbot.data.schedulers',
         'buildbot.data.forceschedulers',
         'buildbot.data.root',
+        'buildbot.data.projects',
         'buildbot.data.properties',
         'buildbot.data.test_results',
         'buildbot.data.test_result_sets',
@@ -166,10 +167,12 @@ class DataConnector(service.AsyncService):
         """
         paths = []
         for k, v in sorted(self.matcher.iterPatterns()):
-            paths.append(dict(path="/".join(k),
-                              plural=str(v.rtype.plural),
-                              type=str(v.rtype.entityType.name),
-                              type_spec=v.rtype.entityType.getSpec()))
+            paths.append({
+                "path": '/'.join(k),
+                "plural": str(v.rtype.plural),
+                "type": str(v.rtype.entityType.name),
+                "type_spec": v.rtype.entityType.getSpec()
+            })
         return paths
 
     def resultspec_from_jsonapi(self, req_args, entityType, is_collection):
@@ -180,7 +183,7 @@ class DataConnector(service.AsyncService):
                 if k[0] == '-' and negOk:
                     k = k[1:]
                 if k not in entityType.fieldNames:
-                    raise exceptions.InvalidQueryParameter("no such field '{}'".format(k))
+                    raise exceptions.InvalidQueryParameter(f"no such field '{k}'")
 
         limit = offset = order = fields = None
         filters, properties = [], []
@@ -189,7 +192,7 @@ class DataConnector(service.AsyncService):
         for arg in req_args:
             argStr = bytes2unicode(arg)
             if argStr == 'order':
-                order = tuple([bytes2unicode(o) for o in req_args[arg]])
+                order = tuple(bytes2unicode(o) for o in req_args[arg])
                 checkFields(order, True)
             elif argStr == 'field':
                 fields = req_args[arg]
@@ -209,12 +212,11 @@ class DataConnector(service.AsyncService):
                     props = []
                     for v in req_args[arg]:
                         if not isinstance(v, (bytes, str)):
-                            raise TypeError(
-                                "Invalid type {} for {}".format(type(v), v))
+                            raise TypeError(f"Invalid type {type(v)} for {v}")
                         props.append(bytes2unicode(v))
                 except Exception as e:
                     raise exceptions.InvalidQueryParameter(
-                        'invalid property value for {}'.format(arg)) from e
+                        f'invalid property value for {arg}') from e
                 properties.append(resultspec.Property(arg, 'eq', props))
             elif argStr in entityType.fieldNames:
                 field = entityType.fields[argStr]
@@ -222,7 +224,7 @@ class DataConnector(service.AsyncService):
                     values = [field.valueFromString(v) for v in req_args[arg]]
                 except Exception as e:
                     raise exceptions.InvalidQueryParameter(
-                        'invalid filter value for {}'.format(argStr)) from e
+                        f'invalid filter value for {argStr}') from e
 
                 filters.append(resultspec.Filter(argStr, 'eq', values))
             elif '__' in argStr:
@@ -238,11 +240,10 @@ class DataConnector(service.AsyncService):
                                   for v in req_args[arg]]
                     except Exception as e:
                         raise exceptions.InvalidQueryParameter(
-                            'invalid filter value for {}'.format(argStr)) from e
+                            f'invalid filter value for {argStr}') from e
                     filters.append(resultspec.Filter(field, op, values))
             else:
-                raise exceptions.InvalidQueryParameter(
-                    "unrecognized query parameter '{}'".format(argStr))
+                raise exceptions.InvalidQueryParameter(f"unrecognized query parameter '{argStr}'")
 
         # if ordering or filtering is on a field that's not in fields, bail out
         if fields:
