@@ -62,7 +62,7 @@ class BaseBasicScheduler(base.BaseScheduler):
                 "fileIsImportant must be a callable")
 
         # initialize parent classes
-        base.BaseScheduler.__init__(self, name, builderNames, **kwargs)
+        super().__init__(name, builderNames, **kwargs)
 
         self.treeStableTimer = treeStableTimer
         if fileIsImportant is not None:
@@ -86,7 +86,7 @@ class BaseBasicScheduler(base.BaseScheduler):
 
     @defer.inlineCallbacks
     def activate(self):
-        yield base.BaseScheduler.activate(self)
+        yield super().activate()
 
         if not self.enabled:
             return
@@ -109,7 +109,7 @@ class BaseBasicScheduler(base.BaseScheduler):
     @defer.inlineCallbacks
     def deactivate(self):
         # the base deactivate will unsubscribe from new changes
-        yield base.BaseScheduler.deactivate(self)
+        yield super().deactivate()
 
         if not self.enabled:
             return
@@ -131,7 +131,8 @@ class BaseBasicScheduler(base.BaseScheduler):
                 return defer.succeed(None)
             # otherwise, we'll build it right away
             return self.addBuildsetForChanges(reason=self.reason,
-                                              changeids=[change.number])
+                                              changeids=[change.number],
+                                              priority=self.priority)
 
         timer_name = self.getTimerNameForChange(change)
 
@@ -199,29 +200,30 @@ class BaseBasicScheduler(base.BaseScheduler):
 
         changeids = sorted(classifications.keys())
         yield self.addBuildsetForChanges(reason=self.reason,
-                                         changeids=changeids)
+                                         changeids=changeids,
+                                         priority=self.priority)
 
         max_changeid = changeids[-1]  # (changeids are sorted)
         yield self.master.db.schedulers.flushChangeClassifications(
             self.serviceid, less_than=max_changeid + 1)
 
 
-class SingleBranchScheduler(BaseBasicScheduler, AbsoluteSourceStampsMixin):
+class SingleBranchScheduler(AbsoluteSourceStampsMixin, BaseBasicScheduler):
 
     def __init__(self, name, createAbsoluteSourceStamps=False, **kwargs):
         self.createAbsoluteSourceStamps = createAbsoluteSourceStamps
-        BaseBasicScheduler.__init__(self, name, **kwargs)
+        super().__init__(name, **kwargs)
 
     @defer.inlineCallbacks
     def gotChange(self, change, important):
         if self.createAbsoluteSourceStamps:
             yield self.recordChange(change)
 
-        yield BaseBasicScheduler.gotChange(self, change, important)
+        yield super().gotChange(change, important)
 
     def getCodebaseDict(self, codebase):
         if self.createAbsoluteSourceStamps:
-            return AbsoluteSourceStampsMixin.getCodebaseDict(self, codebase)
+            return super().getCodebaseDict(codebase)
         return self.codebases[codebase]
 
     def getChangeFilter(self, branch, branches, change_filter, categories):
@@ -254,7 +256,7 @@ class Scheduler(SingleBranchScheduler):
                 "buildbot.schedulers.basic.SingleBranchScheduler instead " +
                 "(note that this may require you to change your import " +
                 "statement)")
-        SingleBranchScheduler.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class AnyBranchScheduler(BaseBasicScheduler):
