@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 # old (pre-0.8.4) location for ChangeFilter
 from buildbot.changes.filter import ChangeFilter
