@@ -70,16 +70,16 @@ class CMake(ShellMixin, BuildStep):
                 '-G', self.generator
             ])
 
-        if self.path:
-            command.append(self.path)
-
         if self.definitions is not None:
             for item in self.definitions.items():
-                command.append('-D%s=%s' % item)
+                command.append(f'-D{item[0]}={item[1]}')
 
         if self.options is not None:
             command.extend(self.options)
 
+        if self.path:
+            command.append(self.path)
+
         cmd = yield self.makeRemoteShellCommand(command=command)
 
         yield self.runCommand(cmd)
