@@ -143,7 +143,7 @@ class DebPbuilder(WarningCountingShellCommand):
             if self.extrapackages:
                 command += ['--extrapackages', " ".join(self.extrapackages)]
             if self.keyring:
-                command += ['--debootstrapopts', "--keyring={}".format(self.keyring)]
+                command += ['--debootstrapopts', f"--keyring={self.keyring}"]
             if self.components:
                 command += ['--components', self.components]
 
@@ -157,7 +157,7 @@ class DebPbuilder(WarningCountingShellCommand):
 
             yield self.runCommand(cmd)
             if cmd.rc != 0:
-                log.msg("Failure when running {}.".format(cmd))
+                log.msg(f"Failure when running {cmd}.")
                 return results.FAILURE
             return results.SUCCESS
 
@@ -165,7 +165,7 @@ class DebPbuilder(WarningCountingShellCommand):
         # basetgz will be a file when running in pbuilder
         # and a directory in case of cowbuilder
         if stat.S_ISREG(s[stat.ST_MODE]) or stat.S_ISDIR(s[stat.ST_MODE]):
-            log.msg("{} found.".format(self.basetgz))
+            log.msg(f"{self.basetgz} found.")
             age = time.time() - s[stat.ST_MTIME]
             if age >= self.maxAge:
                 log.msg("basetgz outdated, updating")
@@ -178,17 +178,17 @@ class DebPbuilder(WarningCountingShellCommand):
 
                 yield self.runCommand(cmd)
                 if cmd.rc != 0:
-                    log.msg("Failure when running {}.".format(cmd))
+                    log.msg(f"Failure when running {cmd}.")
                     return results.FAILURE
             return results.SUCCESS
 
-        log.msg("{} is not a file or a directory.".format(self.basetgz))
+        log.msg(f"{self.basetgz} is not a file or a directory.")
         return results.FAILURE
 
     def logConsumer(self):
         r = re.compile(r"dpkg-genchanges  >\.\./(.+\.changes)")
         while True:
-            stream, line = yield
+            _, line = yield
             mo = r.search(line)
             if mo:
                 self.setProperty("deb-changes", mo.group(1), "DebPbuilder")
