@@ -14,14 +14,16 @@
 # Copyright Buildbot Team Members
 
 
+import io
 from unittest import TestResult
 
-from twisted.python.compat import NativeStringIO
+from twisted.internet import defer
 
+from buildbot.process import buildstep
 from buildbot.process import logobserver
 from buildbot.process.results import FAILURE
 from buildbot.process.results import SUCCESS
-from buildbot.steps.shell import ShellCommand
+from buildbot.process.results import statusToString
 
 
 class SubunitLogObserver(logobserver.LogLineObserver, TestResult):
@@ -33,51 +35,50 @@ class SubunitLogObserver(logobserver.LogLineObserver, TestResult):
     """
 
     def __init__(self):
-        logobserver.LogLineObserver.__init__(self)
-        TestResult.__init__(self)
+        super().__init__()
         try:
-            from subunit import TestProtocolServer, PROGRESS_CUR, PROGRESS_SET
-            from subunit import PROGRESS_PUSH, PROGRESS_POP
-        except ImportError:
+            from subunit import PROGRESS_CUR
+            from subunit import PROGRESS_POP
+            from subunit import PROGRESS_PUSH
+            from subunit import PROGRESS_SET
+            from subunit import TestProtocolServer
+        except ImportError as e:
             raise ImportError("subunit is not importable, but is required for "
-                              "SubunitLogObserver support.")
+                              "SubunitLogObserver support.") from e
         self.PROGRESS_CUR = PROGRESS_CUR
         self.PROGRESS_SET = PROGRESS_SET
         self.PROGRESS_PUSH = PROGRESS_PUSH
         self.PROGRESS_POP = PROGRESS_POP
-        self.warningio = NativeStringIO()
+        self.warningio = io.BytesIO()
         self.protocol = TestProtocolServer(self, self.warningio)
         self.skips = []
         self.seen_tags = set()  # don't yet know what tags does in subunit
 
     def outLineReceived(self, line):
-        """Process a received stdout line."""
         # Impedance mismatch: subunit wants lines, observers get lines-no\n
-        self.protocol.lineReceived(line + '\n')
+        # Note that observers get already decoded lines whereas protocol wants bytes
+        self.protocol.lineReceived(line.encode('utf-8') + b'\n')
 
     def errLineReceived(self, line):
-        """same for stderr line."""
-        self.protocol.lineReceived(line + '\n')
+        # Same note as in outLineReceived applies
+        self.protocol.lineReceived(line.encode('utf-8') + b'\n')
 
     def stopTest(self, test):
-        TestResult.stopTest(self, test)
+        super().stopTest(test)
         self.step.setProgress('tests', self.testsRun)
 
-    def addSuccess(self, test):
-        TestResult.addSuccess(self, test)
-
     def addSkip(self, test, detail):
         if hasattr(TestResult, 'addSkip'):
-            TestResult.addSkip(self, test, detail)
+            super().addSkip(test, detail)
         else:
             self.skips.append((test, detail))
 
     def addError(self, test, err):
-        TestResult.addError(self, test, err)
+        super().addError(test, err)
         self.issue(test, err)
 
     def addFailure(self, test, err):
-        TestResult.addFailure(self, test, err)
+        super().addFailure(test, err)
         self.issue(test, err)
 
     def issue(self, test, err):
@@ -90,81 +91,84 @@ class SubunitLogObserver(logobserver.LogLineObserver, TestResult):
         self.seen_tags.update(new_tags)
 
 
-class SubunitShellCommand(ShellCommand):
+class SubunitShellCommand(buildstep.ShellMixin, buildstep.BuildStep):
+    name = 'shell'
 
     """A ShellCommand that sniffs subunit output.
     """
 
     def __init__(self, failureOnNoTests=False, *args, **kwargs):
-        ShellCommand.__init__(self, *args, **kwargs)
+        kwargs = self.setupShellMixin(kwargs)
+        super().__init__(*args, **kwargs)
+
         self.failureOnNoTests = failureOnNoTests
 
-        self.ioObserver = SubunitLogObserver()
-        self.addLogObserver('stdio', self.ioObserver)
+        self._observer = SubunitLogObserver()
+        self.addLogObserver('stdio', self._observer)
         self.progressMetrics = self.progressMetrics + ('tests', 'tests failed')
 
-    def commandComplete(self, cmd):
-        # figure out all statistics about the run
-        ob = self.ioObserver
-        failures = len(ob.failures)
-        errors = len(ob.errors)
-        skips = len(ob.skips)
-        total = ob.testsRun
+    @defer.inlineCallbacks
+    def run(self):
+        cmd = yield self.makeRemoteShellCommand()
+        yield self.runCommand(cmd)
+
+        stdio_log = yield self.getLog('stdio')
+        yield stdio_log.finish()
+
+        problems = ""
+        for test, err in self._observer.errors + self._observer.failures:
+            problems += f"{test.id()}\n{err}"
+        if problems:
+            yield self.addCompleteLog("problems", problems)
+
+        warnings = self._observer.warningio.getvalue()
+        if warnings:
+            yield self.addCompleteLog("warnings", warnings)
+
+        failures = len(self._observer.failures)
+        errors = len(self._observer.errors)
+        total = self._observer.testsRun
+
+        if cmd.didFail():
+            return FAILURE
+
+        if failures + errors > 0:
+            return FAILURE
+
+        if not total and self.failureOnNoTests:
+            return FAILURE
+        return SUCCESS
+
+    def getResultSummary(self):
+        failures = len(self._observer.failures)
+        errors = len(self._observer.errors)
+        skips = len(self._observer.skips)
+        total = self._observer.testsRun
 
         count = failures + errors
 
-        text = [self.name]
-        text2 = ""
+        summary = self.name
 
         if not count:
-            results = SUCCESS
             if total:
-                text += ["%d %s" %
-                         (total,
-                          total == 1 and "test" or "tests"),
-                         "passed"]
+                summary += f' {total} {total == 1 and "test" or "tests"} passed'
             else:
-                if self.failureOnNoTests:
-                    results = FAILURE
-                text += ["no tests", "run"]
+                summary += " no tests run"
         else:
-            results = FAILURE
-            text.append("Total %d test(s)" % total)
+            summary += f" Total {total} test(s)"
             if failures:
-                text.append("%d %s" %
-                            (failures,
-                             failures == 1 and "failure" or "failures"))
+                summary += f' {failures} {failures == 1 and "failure" or "failures"}'
             if errors:
-                text.append("%d %s" %
-                            (errors,
-                             errors == 1 and "error" or "errors"))
-            text2 = "%d %s" % (count, (count == 1 and 'test' or 'tests'))
+                summary += f' {errors} {errors == 1 and "error" or "errors"}'
 
         if skips:
-            text.append("%d %s" % (skips,
-                                   skips == 1 and "skip" or "skips"))
+            summary += f' {skips} {skips == 1 and "skip" or "skips"}'
 
         # TODO: expectedFailures/unexpectedSuccesses
 
-        self.results = results
-        self.text = text
-        self.text2 = [text2]
+        if self.results != SUCCESS:
+            summary += f' ({statusToString(self.results)})'
+            if self.timed_out:
+                summary += " (timed out)"
 
-    def evaluateCommand(self, cmd):
-        if cmd.didFail():
-            return FAILURE
-        return self.results
-
-    def createSummary(self, loog):
-        ob = self.ioObserver
-        problems = ""
-        for test, err in ob.errors + ob.failures:
-            problems += "%s\n%s" % (test.id(), err)
-        if problems:
-            self.addCompleteLog("problems", problems)
-        warnings = ob.warningio.getvalue()
-        if warnings:
-            self.addCompleteLog("warnings", warnings)
-
-    def _describe(self, done):
-        return self.text
+        return {'step': summary}
