@@ -25,37 +25,28 @@ from buildbot.util import epoch2datetime
 class Patch(Row):
     table = "patches"
 
-    defaults = dict(
-        id=None,
-        patchlevel=0,
-        patch_base64='aGVsbG8sIHdvcmxk',  # 'hello, world',
-        patch_author=None,
-        patch_comment=None,
-        subdir=None,
-    )
-
     id_column = 'id'
 
+    def __init__(self, id=None, patchlevel=0,
+                 patch_base64='aGVsbG8sIHdvcmxk',  # 'hello, world',
+                 patch_author=None, patch_comment=None, subdir=None):
+        super().__init__(id=id, patchlevel=patchlevel, patch_base64=patch_base64,
+                         patch_author=patch_author, patch_comment=patch_comment, subdir=subdir)
+
 
 class SourceStamp(Row):
     table = "sourcestamps"
 
-    defaults = dict(
-        id=None,
-        branch='master',
-        revision='abcd',
-        patchid=None,
-        repository='repo',
-        codebase='',
-        project='proj',
-        created_at=89834834,
-        ss_hash=None,
-    )
-
     id_column = 'id'
     hashedColumns = [('ss_hash', ('branch', 'revision', 'repository',
                                   'project', 'codebase', 'patchid',))]
 
+    def __init__(self, id=None, branch='master', revision='abcd', patchid=None, repository='repo',
+                 codebase='', project='proj', created_at=89834834, ss_hash=None):
+        super().__init__(id=id, branch=branch, revision=revision, patchid=patchid,
+                         repository=repository, codebase=codebase, project=project,
+                         created_at=created_at, ss_hash=ss_hash)
+
 
 class FakeSourceStampsComponent(FakeDBComponent):
 
@@ -63,15 +54,16 @@ class FakeSourceStampsComponent(FakeDBComponent):
         self.sourcestamps = {}
         self.patches = {}
 
-    def insertTestData(self, rows):
+    def insert_test_data(self, rows):
         for row in rows:
             if isinstance(row, Patch):
-                self.patches[row.id] = dict(
-                    patch_level=row.patchlevel,
-                    patch_body=base64.b64decode(row.patch_base64),
-                    patch_author=row.patch_author,
-                    patch_comment=row.patch_comment,
-                    patch_subdir=row.subdir)
+                self.patches[row.id] = {
+                    "patch_level": row.patchlevel,
+                    "patch_body": base64.b64decode(row.patch_base64),
+                    "patch_author": row.patch_author,
+                    "patch_comment": row.patch_comment,
+                    "patch_subdir": row.subdir
+                }
 
         for row in rows:
             if isinstance(row, SourceStamp):
@@ -107,19 +99,25 @@ class FakeSourceStampsComponent(FakeDBComponent):
             patchid = len(self.patches) + 1
             while patchid in self.patches:
                 patchid += 1
-            self.patches[patchid] = dict(
-                patch_level=patch_level,
-                patch_body=patch_body,
-                patch_subdir=patch_subdir,
-                patch_author=patch_author,
-                patch_comment=patch_comment
-            )
+            self.patches[patchid] = {
+                "patch_level": patch_level,
+                "patch_body": patch_body,
+                "patch_subdir": patch_subdir,
+                "patch_author": patch_author,
+                "patch_comment": patch_comment
+            }
         else:
             patchid = None
 
-        new_ssdict = dict(branch=branch, revision=revision, codebase=codebase,
-                          patchid=patchid, repository=repository, project=project,
-                          created_at=epoch2datetime(self.reactor.seconds()))
+        new_ssdict = {
+            "branch": branch,
+            "revision": revision,
+            "codebase": codebase,
+            "patchid": patchid,
+            "repository": repository,
+            "project": project,
+            "created_at": epoch2datetime(self.reactor.seconds())
+        }
         for id, ssdict in self.sourcestamps.items():
             keys = ['branch', 'revision', 'repository',
                     'codebase', 'project', 'patchid']
