@@ -18,6 +18,9 @@ import base64
 
 from twisted.internet import defer
 
+from buildbot.reporters.generators.build import BuildStatusGenerator
+from buildbot.reporters.generators.buildset import BuildSetStatusGenerator
+from buildbot.reporters.generators.worker import WorkerMissingGenerator
 from buildbot.reporters.mail import ESMTPSenderFactory
 from buildbot.reporters.mail import MailNotifier
 from buildbot.reporters.message import MessageFormatter
@@ -37,7 +40,13 @@ class NotifierMaster(RunMasterBase):
                 "see: https://twistedmatrix.com/trac/ticket/8770")
 
     @defer.inlineCallbacks
-    def setUp(self):
+    def create_master_config(self, build_set_summary=False):
+        from buildbot.config import BuilderConfig
+        from buildbot.plugins import reporters
+        from buildbot.plugins import schedulers
+        from buildbot.plugins import steps
+        from buildbot.process.factory import BuildFactory
+
         self.mailDeferred = defer.Deferred()
 
         # patch MailNotifier.sendmail to know when the mail has been sent
@@ -51,31 +60,79 @@ class NotifierMaster(RunMasterBase):
             self.notification.callback(params)
         self.patch(PushoverNotifier, "sendNotification", sendNotification)
 
-        yield self.setupConfig(masterConfig())
+        c = {}
+        c['schedulers'] = [
+            schedulers.AnyBranchScheduler(
+                name="sched",
+                builderNames=["testy"])
+        ]
+        f = BuildFactory()
+        f.addStep(steps.ShellCommand(command='echo hello'))
+        c['builders'] = [
+            BuilderConfig(name="testy",
+                          workernames=["local1"],
+                          factory=f)
+        ]
+
+        formatter = MessageFormatter(template='This is a message.')
+        formatter_worker = MessageFormatterMissingWorker(template='No worker.')
+
+        if build_set_summary:
+            generators_mail = [
+                BuildSetStatusGenerator(mode='all'),
+                WorkerMissingGenerator(workers='all'),
+            ]
+            generators_pushover = [
+                BuildSetStatusGenerator(mode='all', message_formatter=formatter),
+                WorkerMissingGenerator(workers=['local1'], message_formatter=formatter_worker),
+            ]
+        else:
+            generators_mail = [
+                BuildStatusGenerator(mode='all'),
+                WorkerMissingGenerator(workers='all'),
+            ]
+            generators_pushover = [
+                BuildStatusGenerator(mode='all', message_formatter=formatter),
+                WorkerMissingGenerator(workers=['local1'], message_formatter=formatter_worker),
+            ]
+
+        c['services'] = [
+            reporters.MailNotifier("bot@foo.com", generators=generators_mail),
+            reporters.PushoverNotifier('1234', 'abcd', generators=generators_pushover)
+        ]
+
+        yield self.setup_master(c)
 
     @defer.inlineCallbacks
     def doTest(self, what):
-        change = dict(branch="master",
-                      files=["foo.c"],
-                      author="author@foo.com",
-                      comments="good stuff",
-                      revision="HEAD",
-                      project="none"
-                      )
+        change = {
+            "branch": "master",
+            "files": ["foo.c"],
+            "author": "author@foo.com",
+            "committer": "me@foo.com",
+            "comments": "good stuff",
+            "revision": "HEAD",
+            "project": "projectname"
+        }
         build = yield self.doForceBuild(wantSteps=True, useChange=change, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
         mail, recipients = yield self.mailDeferred
         self.assertEqual(recipients, ["author@foo.com"])
         self.assertIn("From: bot@foo.com", mail)
-        self.assertIn("Subject: Buildbot success in Buildbot", mail)
-        self.assertEncodedIn("The Buildbot has detected a passing build", mail)
+        self.assertIn(f"Subject: =?utf-8?q?=E2=98=BA_Buildbot_=28Buildbot=29=3A_{what}_-_build_successful_=28master=29?=\n",  # noqa pylint: disable=line-too-long
+                      mail)
+        self.assertEncodedIn("A passing build has been detected on builder testy while", mail)
         params = yield self.notification
         self.assertEqual(build['buildid'], 1)
-        self.assertEqual(params, {'title': "Buildbot success in Buildbot on {}".format(what),
-                                  'message': "This is a message."})
+        self.assertEqual(params, {
+            'title': f"☺ Buildbot (Buildbot): {what} - build successful (master)",
+            'message': "This is a message."
+        })
 
     def assertEncodedIn(self, text, mail):
-        # python 2.6 default transfer in base64 for utf-8
+        # The default transfer encoding is base64 for utf-8 even when it could be represented
+        # accurately by quoted 7bit encoding. TODO: it is possible to override it,
+        # see https://bugs.python.org/issue12552
         if "base64" not in mail:
             self.assertIn(text, mail)
         else:  # b64encode and remove '=' padding (hence [:-1])
@@ -85,19 +142,17 @@ class NotifierMaster(RunMasterBase):
 
     @defer.inlineCallbacks
     def test_notifiy_for_build(self):
+        yield self.create_master_config(build_set_summary=False)
         yield self.doTest('testy')
 
     @defer.inlineCallbacks
     def test_notifiy_for_buildset(self):
-        self.master.config.services = [
-            MailNotifier("bot@foo.com", mode="all", buildSetSummary=True),
-            PushoverNotifier('1234', 'abcd', mode="all", buildSetSummary=True,
-                messageFormatter=MessageFormatter(template='This is a message.'))]
-        yield self.master.reconfigServiceWithBuildbotConfig(self.master.config)
-        yield self.doTest('whole buildset')
+        yield self.create_master_config(build_set_summary=True)
+        yield self.doTest('projectname')
 
     @defer.inlineCallbacks
     def test_missing_worker(self):
+        yield self.create_master_config(build_set_summary=False)
         yield self.master.data.updates.workerMissing(
             workerid='local1',
             masterid=self.master.masterid,
@@ -107,38 +162,9 @@ class NotifierMaster(RunMasterBase):
         mail, recipients = yield self.mailDeferred
         self.assertIn("From: bot@foo.com", mail)
         self.assertEqual(recipients, ['admin@worker.org'])
-        self.assertIn("Subject: Buildbot worker local1 missing", mail)
+        self.assertIn("Subject: Buildbot Buildbot worker local1 missing", mail)
         self.assertIn("disconnected at long time ago", mail)
         self.assertEncodedIn("worker named local1 went away", mail)
         params = yield self.notification
-        self.assertEqual(params, {'title': "Buildbot worker local1 missing",
+        self.assertEqual(params, {'title': "Buildbot Buildbot worker local1 missing",
                                   'message': b"No worker."})
-
-
-# master configuration
-def masterConfig():
-    c = {}
-    from buildbot.config import BuilderConfig
-    from buildbot.process.factory import BuildFactory
-    from buildbot.plugins import steps, schedulers, reporters
-    c['schedulers'] = [
-        schedulers.AnyBranchScheduler(
-            name="sched",
-            builderNames=["testy"])
-    ]
-    f = BuildFactory()
-    f.addStep(steps.ShellCommand(command='echo hello'))
-    c['builders'] = [
-        BuilderConfig(name="testy",
-                      workernames=["local1"],
-                      factory=f)
-    ]
-    notifier = reporters.PushoverNotifier('1234', 'abcd', mode="all", watchedWorkers=['local1'],
-                                          messageFormatter=MessageFormatter(template='This is a message.'),
-                                          messageFormatterMissingWorker=MessageFormatterMissingWorker(
-                                              template='No worker.'))
-    c['services'] = [
-        reporters.MailNotifier("bot@foo.com", mode="all"),
-        notifier
-    ]
-    return c
