@@ -17,9 +17,10 @@
 import importlib
 import inspect
 import os
-import pkg_resources
 import warnings
 
+from packaging.version import parse as parse_version
+
 import twisted
 from twisted.trial import unittest
 from twisted.trial.unittest import SkipTest
@@ -96,7 +97,7 @@ class TestSetupPyEntryPoints(unittest.TestCase):
 
     def test_util(self):
         # work around Twisted bug 9384.
-        if pkg_resources.parse_version(twisted.__version__) < pkg_resources.parse_version("18.9.0"):
+        if parse_version(twisted.__version__) < parse_version("18.9.0"):
             raise SkipTest('manhole.py can not be imported on old twisted and new python')
 
         known_not_exported = {
@@ -220,7 +221,7 @@ class TestSetupPyEntryPoints(unittest.TestCase):
         # Now verify that are no unregistered plugins left.
         existing_classes = self.get_existing_classes(module_name, interface)
 
-        exported_classes = {f'{plugins._get_entry(name)._entry.module_name}.{name}'
+        exported_classes = {f'{plugins._get_entry(name)._entry.module}.{name}'
                             for name in plugins.names}
         if known_not_exported is None:
             known_not_exported = set()
