@@ -27,88 +27,89 @@ from buildbot.process.factory import BuildFactory
 from buildbot.process.results import CANCELLED
 from buildbot.test.util.integration import RunMasterBase
 
+
 # This integration test creates a master and worker environment,
 # with two builders and a trigger step linking them. the triggered build never ends
 # so that we can reliably stop it recursively
-
-
-# master configurations
-def setupTriggerConfiguration(triggeredFactory, nextBuild=None):
-    c = {}
-
-    c['schedulers'] = [
-        schedulers.Triggerable(
-            name="trigsched",
-            builderNames=["triggered"]),
-        schedulers.AnyBranchScheduler(
-            name="sched",
-            builderNames=["main"])]
-
-    f = BuildFactory()
-    f.addStep(steps.Trigger(schedulerNames=['trigsched'],
-                            waitForFinish=True,
-                            updateSourceStamp=True))
-    f.addStep(steps.ShellCommand(command='echo world'))
-
-    mainBuilder = BuilderConfig(name="main",
-                                workernames=["local1"],
-                                factory=f)
-
-    triggeredBuilderKwargs = {'name': "triggered",
-                              'workernames': ["local1"],
-                              'factory': triggeredFactory}
-
-    if nextBuild is not None:
-        triggeredBuilderKwargs['nextBuild'] = nextBuild
-
-    triggeredBuilder = BuilderConfig(**triggeredBuilderKwargs)
-
-    c['builders'] = [mainBuilder, triggeredBuilder]
-    return c
-
-
-def triggerRunsForever():
-    f2 = BuildFactory()
-
-    # Infinite sleep command.
-    if sys.platform == 'win32':
-        # Ping localhost infinitely.
-        # There are other options, however they either don't work in
-        # non-interactive mode (e.g. 'pause'), or doesn't available on all
-        # Windows versions (e.g. 'timeout' and 'choice' are available
-        # starting from Windows 7).
-        cmd = 'ping -t 127.0.0.1'.split()
-    else:
-        cmd = textwrap.dedent("""\
-            while :
-            do
-              echo "sleeping";
-              sleep 1;
-            done
-            """)
-
-    f2.addStep(steps.ShellCommand(command=cmd))
-
-    return setupTriggerConfiguration(f2)
-
-
-def triggeredBuildIsNotCreated():
-    f2 = BuildFactory()
-    f2.addStep(steps.ShellCommand(command="echo 'hello'"))
-
-    def nextBuild(*args, **kwargs):
-        return defer.succeed(None)
-    return setupTriggerConfiguration(f2, nextBuild=nextBuild)
-
-
 class TriggeringMaster(RunMasterBase):
     timeout = 120
-    change = dict(branch="master",
-                  files=["foo.c"],
-                  author="me@foo.com",
-                  comments="good stuff",
-                  revision="HEAD",
-                  project="none")
+    change = {
+        "branch": "master",
+        "files": ["foo.c"],
+        "author": "me@foo.com",
+        "committer": "me@foo.com",
+        "comments": "good stuff",
+        "revision": "HEAD",
+        "project": "none"
+    }
+
+    @defer.inlineCallbacks
+    def setup_trigger_config(self, triggeredFactory, nextBuild=None):
+        c = {}
+
+        c['schedulers'] = [
+            schedulers.Triggerable(
+                name="trigsched",
+                builderNames=["triggered"]),
+            schedulers.AnyBranchScheduler(
+                name="sched",
+                builderNames=["main"])]
+
+        f = BuildFactory()
+        f.addStep(steps.Trigger(schedulerNames=['trigsched'],
+                                waitForFinish=True,
+                                updateSourceStamp=True))
+        f.addStep(steps.ShellCommand(command='echo world'))
+
+        mainBuilder = BuilderConfig(name="main",
+                                    workernames=["local1"],
+                                    factory=f)
+
+        triggeredBuilderKwargs = {'name': "triggered",
+                                  'workernames': ["local1"],
+                                  'factory': triggeredFactory}
+
+        if nextBuild is not None:
+            triggeredBuilderKwargs['nextBuild'] = nextBuild
+
+        triggeredBuilder = BuilderConfig(**triggeredBuilderKwargs)
+
+        c['builders'] = [mainBuilder, triggeredBuilder]
+        yield self.setup_master(c)
+
+    @defer.inlineCallbacks
+    def setup_config_trigger_runs_forever(self):
+        f2 = BuildFactory()
+
+        # Infinite sleep command.
+        if sys.platform == 'win32':
+            # Ping localhost infinitely.
+            # There are other options, however they either don't work in
+            # non-interactive mode (e.g. 'pause'), or doesn't available on all
+            # Windows versions (e.g. 'timeout' and 'choice' are available
+            # starting from Windows 7).
+            cmd = 'ping -t 127.0.0.1'.split()
+        else:
+            cmd = textwrap.dedent("""\
+                while :
+                do
+                  echo "sleeping";
+                  sleep 1;
+                done
+                """)
+
+        f2.addStep(steps.ShellCommand(command=cmd))
+
+        yield self.setup_trigger_config(f2)
+
+    @defer.inlineCallbacks
+    def setup_config_triggered_build_not_created(self):
+        f2 = BuildFactory()
+        f2.addStep(steps.ShellCommand(command="echo 'hello'"))
+
+        def nextBuild(*args, **kwargs):
+            return defer.succeed(None)
+        yield self.setup_trigger_config(f2, nextBuild=nextBuild)
 
     def assertBuildIsCancelled(self, b):
         self.assertTrue(b['complete'])
@@ -132,7 +133,7 @@ class TriggeringMaster(RunMasterBase):
 
     @defer.inlineCallbacks
     def testTriggerRunsForever(self):
-        yield self.setupConfig(triggerRunsForever())
+        yield self.setup_config_trigger_runs_forever()
         self.higherBuild = None
 
         def newCallback(_, data):
@@ -146,7 +147,7 @@ class TriggeringMaster(RunMasterBase):
 
     @defer.inlineCallbacks
     def testTriggerRunsForeverAfterCmdStarted(self):
-        yield self.setupConfig(triggerRunsForever())
+        yield self.setup_config_trigger_runs_forever()
         self.higherBuild = None
 
         def newCallback(_, data):
@@ -164,7 +165,7 @@ class TriggeringMaster(RunMasterBase):
 
     @defer.inlineCallbacks
     def testTriggeredBuildIsNotCreated(self):
-        yield self.setupConfig(triggeredBuildIsNotCreated())
+        yield self.setup_config_triggered_build_not_created()
 
         def newCallback(_, data):
             self.master.data.control("stop", {}, ("builds", data['buildid']))
