@@ -34,9 +34,9 @@ from buildbot.db import connector
 from buildbot.db.model import UpgradeFromBefore0p9Error
 from buildbot.db.model import UpgradeFromBefore3p0Error
 from buildbot.test.fake import fakemaster
+from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import db
 from buildbot.test.util import querylog
-from buildbot.test.util.misc import TestReactorMixin
 
 
 class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
@@ -71,15 +71,18 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
         if self.source_tarball:
             tarball = util.sibpath(__file__, self.source_tarball)
             if not os.path.exists(tarball):
-                raise unittest.SkipTest("'{}' not found (normal when not building from Git)".format(
-                        tarball))
+                raise unittest.SkipTest(
+                    f"'{tarball}' not found (normal when not building from Git)")
+
+            with tarfile.open(tarball) as tf:
+                prefixes = set()
+                for inf in tf:
+                    if hasattr(tarfile, 'data_filter'):
+                        tf.extract(inf, filter='data')
+                    else:
+                        tf.extract(inf)
+                    prefixes.add(inf.name.split('/', 1)[0])
 
-            tf = tarfile.open(tarball)
-            prefixes = set()
-            for inf in tf:
-                tf.extract(inf)
-                prefixes.add(inf.name.split('/', 1)[0])
-            tf.close()
             # (note that tf.extractall isn't available in py2.4)
 
             # get the top-level dir from the tarball
@@ -111,7 +114,7 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
     # save subclasses the trouble of calling our setUp and tearDown methods
 
     def setUp(self):
-        self.setUpTestReactor()
+        self.setup_test_reactor()
         return self.setUpUpgradeTest()
 
     def tearDown(self):
@@ -137,10 +140,14 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
             diff = []
             for tbl in self.db.model.metadata.sorted_tables:
                 exp = sorted([
-                    dict(name=idx.name,
-                         unique=idx.unique and 1 or 0,
-                         column_names=sorted([c.name for c in idx.columns]))
-                    for idx in tbl.indexes], key=lambda x: x['name'])
+                    {
+                        "name": idx.name,
+                        "unique": idx.unique and 1 or 0,
+                        "column_names": sorted([c.name for c in idx.columns])
+                    }
+                    for idx in tbl.indexes
+                ], key=lambda x: x['name']
+            )
 
                 # include implied indexes on postgres and mysql
                 if engine.dialect.name == 'mysql':
@@ -157,31 +164,33 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
                     got_info = dict((idx['name'], idx) for idx in got)
                     exp_info = dict((idx['name'], idx) for idx in exp)
                     for name in got_names - exp_names:
-                        diff.append("got unexpected index {} on table {}: {}".format(name, tbl.name,
-                                repr(got_info[name])))
+                        diff.append(f"got unexpected index {name} on table {tbl.name}: "
+                                    f"{repr(got_info[name])}")
                     for name in exp_names - got_names:
-                        diff.append("missing index {} on table {}".format(name, tbl.name))
+                        diff.append(f"missing index {name} on table {tbl.name}")
                     for name in got_names & exp_names:
-                        gi = dict(name=name,
-                                  unique=got_info[name]['unique'] and 1 or 0,
-                                  column_names=sorted(got_info[name]['column_names']))
+                        gi = {
+                            "name": name,
+                            "unique": got_info[name]['unique'] and 1 or 0,
+                            "column_names": sorted(got_info[name]['column_names'])
+                        }
                         ei = exp_info[name]
                         if gi != ei:
-                            diff.append(("index {} on table {} differs: got {}; exp {}"
-                                         ).format(name, tbl.name, gi, ei))
+                            diff.append(f"index {name} on table {tbl.name} differs: "
+                                        f"got {gi}; exp {ei}")
             if diff:
                 return "\n".join(diff)
             return None
 
         try:
             diff = yield self.db.pool.do_with_engine(comp)
-        except TypeError:
+        except TypeError as e:
             # older sqlites cause failures in reflection, which manifest as a
             # TypeError.  Reflection is only used for tests, so we can just skip
             # this test on such platforms.  We still get the advantage of trying
             # the upgrade, at any rate.
             raise unittest.SkipTest("model comparison skipped: bugs in schema "
-                                    "reflection on this sqlite version")
+                                    "reflection on this sqlite version") from e
 
         if diff:
             self.fail("\n" + pprint.pformat(diff))
@@ -222,7 +231,7 @@ class UpgradeTestEmpty(UpgradeTestMixin, unittest.TestCase):
             # Default encoding of Windows console is 'cp1252'
             # which cannot encode the snowman.
             raise unittest.SkipTest("Cannot encode weird unicode "
-                "on this platform with {}".format(os_encoding)) from e
+                f"on this platform with {os_encoding}") from e
 
         yield self.db.model.upgrade()
         yield self.assertModelMatches()
