@@ -28,6 +28,7 @@ from buildbot.util import epoch2datetime
 TIME1 = 2001111
 TIME2 = 2002222
 TIME3 = 2003333
+TIME4 = 2004444
 
 
 class StepEndpoint(endpoint.EndpointMixin, unittest.TestCase):
@@ -37,7 +38,7 @@ class StepEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
     def setUp(self):
         self.setUpEndpoint()
-        self.db.insertTestData([
+        self.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Builder(id=77, name='builder77'),
             fakedb.Master(id=88),
@@ -46,12 +47,12 @@ class StepEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             fakedb.Build(id=30, builderid=77, number=7, masterid=88,
                          buildrequestid=82, workerid=47),
             fakedb.Step(id=70, number=0, name='one', buildid=30,
-                        started_at=TIME1, complete_at=TIME2, results=0),
+                        started_at=TIME1, locks_acquired_at=TIME2, complete_at=TIME3, results=0),
             fakedb.Step(id=71, number=1, name='two', buildid=30,
-                        started_at=TIME2, complete_at=TIME3, results=2,
+                        started_at=TIME2, locks_acquired_at=TIME3, complete_at=TIME4, results=2,
                         urls_json='[{"name":"url","url":"http://url"}]'),
             fakedb.Step(id=72, number=2, name='three', buildid=30,
-                        started_at=TIME3, hidden=True),
+                        started_at=TIME4, hidden=True),
         ])
 
     def tearDown(self):
@@ -68,7 +69,8 @@ class StepEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             'name': 'three',
             'number': 2,
             'results': None,
-            'started_at': epoch2datetime(TIME3),
+            'started_at': epoch2datetime(TIME4),
+            "locks_acquired_at": None,
             'state_string': '',
             'stepid': 72,
             'urls': [],
@@ -122,7 +124,7 @@ class StepsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
     def setUp(self):
         self.setUpEndpoint()
-        self.db.insertTestData([
+        self.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Builder(id=77, name='builder77'),
             fakedb.Master(id=88),
@@ -133,14 +135,14 @@ class StepsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             fakedb.Build(id=31, builderid=77, number=8, masterid=88,
                          buildrequestid=82, workerid=47),
             fakedb.Step(id=70, number=0, name='one', buildid=30,
-                        started_at=TIME1, complete_at=TIME2, results=0),
+                        started_at=TIME1, locks_acquired_at=TIME2, complete_at=TIME3, results=0),
             fakedb.Step(id=71, number=1, name='two', buildid=30,
-                        started_at=TIME2, complete_at=TIME3, results=2,
+                        started_at=TIME2, locks_acquired_at=TIME3, complete_at=TIME4, results=2,
                         urls_json='[{"name":"url","url":"http://url"}]'),
             fakedb.Step(id=72, number=2, name='three', buildid=30,
-                        started_at=TIME3),
+                        started_at=TIME4),
             fakedb.Step(id=73, number=0, name='otherbuild', buildid=31,
-                        started_at=TIME2),
+                        started_at=TIME3),
         ])
 
     def tearDown(self):
@@ -201,6 +203,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': number,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'pending',
             'stepid': stepid,
             'urls': [],
@@ -219,6 +222,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': number,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'pending',
             'urls': [],
             'hidden': False,
@@ -253,6 +257,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": None,
             'state_string': 'pending',
             'stepid': 100,
             'urls': [],
@@ -271,6 +276,50 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": None,
+            'state_string': 'pending',
+            'urls': [],
+            'hidden': False,
+        })
+
+    @defer.inlineCallbacks
+    def test_startStep_acquire_locks(self):
+        self.reactor.advance(TIME1)
+        yield self.master.db.steps.addStep(buildid=10, name='ten',
+                                           state_string='pending')
+        yield self.rtype.startStep(stepid=100)
+        self.reactor.advance(TIME2 - TIME1)
+        self.master.mq.clearProductions()
+        yield self.rtype.set_step_locks_acquired_at(stepid=100)
+
+        msgBody = {
+            'buildid': 10,
+            'complete': False,
+            'complete_at': None,
+            'name': 'ten',
+            'number': 0,
+            'results': None,
+            'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": epoch2datetime(TIME2),
+            'state_string': 'pending',
+            'stepid': 100,
+            'urls': [],
+            'hidden': False,
+        }
+        self.master.mq.assertProductions([
+            (('builds', '10', 'steps', str(100), 'updated'), msgBody),
+            (('steps', str(100), 'updated'), msgBody),
+        ])
+        step = yield self.master.db.steps.getStep(100)
+        self.assertEqual(step, {
+            'buildid': 10,
+            'complete_at': None,
+            'id': 100,
+            'name': 'ten',
+            'number': 0,
+            'results': None,
+            'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": epoch2datetime(TIME2),
             'state_string': 'pending',
             'urls': [],
             'hidden': False,
@@ -297,6 +346,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'hi',
             'stepid': 100,
             'urls': [],
@@ -315,6 +365,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'hi',
             'urls': [],
             'hidden': False,
@@ -333,6 +384,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
                                            state_string='pending')
         self.reactor.advance(TIME1)
         yield self.rtype.startStep(stepid=100)
+        yield self.rtype.set_step_locks_acquired_at(stepid=100)
         self.reactor.advance(TIME2 - TIME1)
         self.master.mq.clearProductions()
         yield self.rtype.finishStep(stepid=100, results=9, hidden=False)
@@ -345,6 +397,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': 9,
             'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": epoch2datetime(TIME1),
             'state_string': 'pending',
             'stepid': 100,
             'urls': [],
@@ -363,6 +416,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': 9,
             'started_at': epoch2datetime(TIME1),
+            "locks_acquired_at": epoch2datetime(TIME1),
             'state_string': 'pending',
             'urls': [],
             'hidden': False,
@@ -389,6 +443,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'pending',
             'stepid': 100,
             'urls': [{'name': 'foo', 'url': 'bar'}],
@@ -407,6 +462,7 @@ class Step(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             'number': 0,
             'results': None,
             'started_at': None,
+            "locks_acquired_at": None,
             'state_string': 'pending',
             'urls': [{'name': 'foo', 'url': 'bar'}],
             'hidden': False,
