@@ -60,43 +60,81 @@ class Tests(interfaces.InterfaceTests):
 
     def test_signature_getBuilders(self):
         @self.assertArgSpecMatches(self.db.builders.getBuilders)
-        def getBuilders(self, masterid=None):
+        def getBuilders(self, masterid=None, projectid=None):
             pass
 
     def test_signature_updateBuilderInfo(self):
         @self.assertArgSpecMatches(self.db.builders.updateBuilderInfo)
-        def updateBuilderInfo(self, builderid, description, tags):
+        def updateBuilderInfo(self, builderid, description, description_format, description_html,
+                              projectid, tags):
             pass
 
     @defer.inlineCallbacks
     def test_updateBuilderInfo(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
+            fakedb.Project(id=123, name="fake_project123"),
+            fakedb.Project(id=124, name="fake_project124"),
             fakedb.Builder(id=7, name='some:builder7'),
             fakedb.Builder(id=8, name='some:builder8'),
         ])
 
-        yield self.db.builders.updateBuilderInfo(7, 'a string which describe the builder',
-                                                 ['cat1', 'cat2'])
-        yield self.db.builders.updateBuilderInfo(8, 'a string which describe the builder', [])
+        yield self.db.builders.updateBuilderInfo(
+            7,
+            'a string which describe the builder',
+            None,
+            None,
+            123,
+            ['cat1', 'cat2']
+        )
+        yield self.db.builders.updateBuilderInfo(
+            8,
+            'a string which describe the builder',
+            None,
+            None,
+            124,
+            []
+        )
         builderdict7 = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict7)
         builderdict7['tags'].sort()  # order is unspecified
-        self.assertEqual(builderdict7,
-                         dict(id=7, name='some:builder7', tags=['cat1', 'cat2'],
-                              masterids=[], description='a string which describe the builder'))
+        self.assertEqual(
+            builderdict7,
+            {
+                "id": 7,
+                "name": 'some:builder7',
+                "tags": ["cat1", "cat2"],
+                "masterids": [],
+                "description": "a string which describe the builder",
+                "description_format": None,
+                "description_html": None,
+                "projectid": 123,
+            }
+        )
+
         builderdict8 = yield self.db.builders.getBuilder(8)
         validation.verifyDbDict(self, 'builderdict', builderdict8)
-        self.assertEqual(builderdict8,
-                         dict(id=8, name='some:builder8', tags=[],
-                              masterids=[], description='a string which describe the builder'))
+        self.assertEqual(
+            builderdict8,
+            {
+                "id": 8,
+                "name": 'some:builder8',
+                "tags": [],
+                "masterids": [],
+                "description": "a string which describe the builder",
+                "description_format": None,
+                "description_html": None,
+                "projectid": 124,
+            }
+        )
 
     @defer.inlineCallbacks
     def test_update_builder_info_tags_case(self):
-        yield self.insertTestData([
-            fakedb.Builder(id=7, name='some:builder7'),
+        yield self.insert_test_data([
+            fakedb.Project(id=107, name='fake_project'),
+            fakedb.Builder(id=7, name='some:builder7', projectid=107),
         ])
 
-        yield self.db.builders.updateBuilderInfo(7, 'builder_desc', ['Cat', 'cat'])
+        yield self.db.builders.updateBuilderInfo(7, 'builder_desc', None, None, 107, ['Cat', 'cat'])
         builder_dict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builder_dict)
         builder_dict['tags'].sort()  # order is unspecified
@@ -105,16 +143,29 @@ class Tests(interfaces.InterfaceTests):
             'name': 'some:builder7',
             'tags': ['Cat', 'cat'],
             'masterids': [],
-            'description': 'builder_desc'
+            'description': 'builder_desc',
+            'description_format': None,
+            'description_html': None,
+            'projectid': 107,
         })
 
     @defer.inlineCallbacks
     def test_findBuilderId_new(self):
         id = yield self.db.builders.findBuilderId('some:builder')
         builderdict = yield self.db.builders.getBuilder(id)
-        self.assertEqual(builderdict,
-                         dict(id=id, name='some:builder', tags=[],
-                              masterids=[], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": id,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_findBuilderId_new_no_autoCreate(self):
@@ -123,7 +174,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_findBuilderId_exists(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7, name='some:builder'),
         ])
         id = yield self.db.builders.findBuilderId('some:builder')
@@ -131,7 +182,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_addBuilderMaster(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7),
             fakedb.Master(id=9, name='abc'),
             fakedb.Master(id=10, name='def'),
@@ -140,13 +191,23 @@ class Tests(interfaces.InterfaceTests):
         yield self.db.builders.addBuilderMaster(builderid=7, masterid=9)
         builderdict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict)
-        self.assertEqual(builderdict,
-                         dict(id=7, name='some:builder', tags=[],
-                              masterids=[9, 10], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [9, 10],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_addBuilderMaster_already_present(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7),
             fakedb.Master(id=9, name='abc'),
             fakedb.Master(id=10, name='def'),
@@ -155,13 +216,23 @@ class Tests(interfaces.InterfaceTests):
         yield self.db.builders.addBuilderMaster(builderid=7, masterid=9)
         builderdict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict)
-        self.assertEqual(builderdict,
-                         dict(id=7, name='some:builder', tags=[],
-                              masterids=[9], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [9],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_removeBuilderMaster(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7),
             fakedb.Master(id=9, name='some:master'),
             fakedb.Master(id=10, name='other:master'),
@@ -171,24 +242,44 @@ class Tests(interfaces.InterfaceTests):
         yield self.db.builders.removeBuilderMaster(builderid=7, masterid=9)
         builderdict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict)
-        self.assertEqual(builderdict,
-                         dict(id=7, name='some:builder', tags=[],
-                              masterids=[10], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [10],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_getBuilder_no_masters(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7, name='some:builder'),
         ])
         builderdict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict)
-        self.assertEqual(builderdict,
-                         dict(id=7, name='some:builder', tags=[],
-                              masterids=[], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_getBuilder_with_masters(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7, name='some:builder'),
             fakedb.Master(id=3, name='m1'),
             fakedb.Master(id=4, name='m2'),
@@ -197,9 +288,19 @@ class Tests(interfaces.InterfaceTests):
         ])
         builderdict = yield self.db.builders.getBuilder(7)
         validation.verifyDbDict(self, 'builderdict', builderdict)
-        self.assertEqual(builderdict,
-                         dict(id=7, name='some:builder', tags=[],
-                              masterids=[3, 4], description=None))
+        self.assertEqual(
+            builderdict,
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [3, 4],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            }
+        )
 
     @defer.inlineCallbacks
     def test_getBuilder_missing(self):
@@ -208,7 +309,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getBuilders(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7, name='some:builder'),
             fakedb.Builder(id=8, name='other:builder'),
             fakedb.Builder(id=9, name='third:builder'),
@@ -222,17 +323,41 @@ class Tests(interfaces.InterfaceTests):
         for builderdict in builderlist:
             validation.verifyDbDict(self, 'builderdict', builderdict)
         self.assertEqual(sorted(builderlist, key=builderKey), sorted([
-            dict(id=7, name='some:builder', masterids=[
-                 3], tags=[], description=None),
-            dict(id=8, name='other:builder', masterids=[
-                 3, 4], tags=[], description=None),
-            dict(id=9, name='third:builder',
-                 masterids=[], tags=[], description=None),
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [3],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            },
+            {
+                "id": 8,
+                "name": 'other:builder',
+                "tags": [],
+                "masterids": [3, 4],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            },
+            {
+                "id": 9,
+                "name": 'third:builder',
+                "tags": [],
+                "masterids": [],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            },
         ], key=builderKey))
 
     @defer.inlineCallbacks
     def test_getBuilders_masterid(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Builder(id=7, name='some:builder'),
             fakedb.Builder(id=8, name='other:builder'),
             fakedb.Builder(id=9, name='third:builder'),
@@ -246,10 +371,68 @@ class Tests(interfaces.InterfaceTests):
         for builderdict in builderlist:
             validation.verifyDbDict(self, 'builderdict', builderdict)
         self.assertEqual(sorted(builderlist, key=builderKey), sorted([
-            dict(id=7, name='some:builder', masterids=[
-                 3], tags=[], description=None),
-            dict(id=8, name='other:builder', masterids=[
-                 3, 4], tags=[], description=None),
+            {
+                "id": 7,
+                "name": 'some:builder',
+                "tags": [],
+                "masterids": [3],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            },
+            {
+                "id": 8,
+                "name": 'other:builder',
+                "tags": [],
+                "masterids": [3, 4],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": None
+            },
+        ], key=builderKey))
+
+    @defer.inlineCallbacks
+    def test_getBuilders_projectid(self):
+        yield self.insert_test_data([
+            fakedb.Project(id=201, name="p201"),
+            fakedb.Project(id=202, name="p202"),
+            fakedb.Builder(id=101, name="b101"),
+            fakedb.Builder(id=102, name="b102", projectid=201),
+            fakedb.Builder(id=103, name="b103", projectid=201),
+            fakedb.Builder(id=104, name="b104", projectid=202),
+            fakedb.Master(id=3, name='m1'),
+            fakedb.Master(id=4, name='m2'),
+            fakedb.BuilderMaster(builderid=101, masterid=3),
+            fakedb.BuilderMaster(builderid=102, masterid=3),
+            fakedb.BuilderMaster(builderid=103, masterid=4),
+            fakedb.BuilderMaster(builderid=104, masterid=4),
+        ])
+        builderlist = yield self.db.builders.getBuilders(projectid=201)
+        for builderdict in builderlist:
+            validation.verifyDbDict(self, 'builderdict', builderdict)
+        self.assertEqual(sorted(builderlist, key=builderKey), sorted([
+            {
+                "id": 102,
+                "name": "b102",
+                "masterids": [3],
+                "tags": [],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": 201,
+            },
+            {
+                "id": 103,
+                "name": "b103",
+                "masterids": [4],
+                "tags": [],
+                "description": None,
+                "description_format": None,
+                "description_html": None,
+                "projectid": 201,
+            },
         ], key=builderKey))
 
     @defer.inlineCallbacks
@@ -279,7 +462,7 @@ class TestRealDB(unittest.TestCase,
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpConnectorComponent(
-            table_names=['builders', 'masters', 'builder_masters',
+            table_names=['projects', 'builders', 'masters', 'builder_masters',
                          'builders_tags', 'tags'])
 
         self.db.builders = builders.BuildersConnectorComponent(self.db)
