@@ -16,8 +16,7 @@
 
 import datetime
 import json
-
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.trial import unittest
@@ -40,7 +39,7 @@ class Tests(interfaces.InterfaceTests):
         self.reactor.advance(self.now)
 
         # set up a sourcestamp with id 234 for use below
-        return self.insertTestData([
+        return self.insert_test_data([
             fakedb.SourceStamp(id=234),
             fakedb.Builder(id=1, name='bldr1'),
             fakedb.Builder(id=2, name='bldr2'),
@@ -50,7 +49,7 @@ class Tests(interfaces.InterfaceTests):
         @self.assertArgSpecMatches(self.db.buildsets.addBuildset)
         def addBuildset(self, sourcestamps, reason, properties,
                         builderids, waited_for, external_idstring=None, submitted_at=None,
-                        parent_buildid=None, parent_relationship=None):
+                        parent_buildid=None, parent_relationship=None, priority=0):
             pass
 
     def test_signature_completeBuildset(self):
@@ -88,13 +87,18 @@ class Tests(interfaces.InterfaceTests):
         # TODO: verify buildrequests too
         bsdict = yield self.db.buildsets.getBuildset(bsid)
         validation.verifyDbDict(self, 'bsdict', bsdict)
-        self.assertEqual(bsdict, dict(external_idstring='extid',
-                                      reason='because', sourcestamps=[234],
-                                      submitted_at=datetime.datetime(1970, 4, 18, 7, 39, 19,
-                                                                     tzinfo=UTC),
-                                      complete=False, complete_at=None, results=-1,
-                                      parent_buildid=None, parent_relationship=None,
-                                      bsid=bsid))
+        self.assertEqual(bsdict, {
+            "external_idstring": 'extid',
+            "reason": 'because',
+            "sourcestamps": [234],
+            "submitted_at": datetime.datetime(1970, 4, 18, 7, 39, 19, tzinfo=UTC),
+            "complete": False,
+            "complete_at": None,
+            "results": -1,
+            "parent_buildid": None,
+            "parent_relationship": None,
+            "bsid": bsid
+        })
 
     @defer.inlineCallbacks
     def test_addBuildset_getBuildset_explicit_submitted_at(self):
@@ -106,17 +110,22 @@ class Tests(interfaces.InterfaceTests):
         bsdict = yield self.db.buildsets.getBuildset(bsid_brids[0])
 
         validation.verifyDbDict(self, 'bsdict', bsdict)
-        self.assertEqual(bsdict, dict(external_idstring='extid',
-                                      reason='because', sourcestamps=[234],
-                                      submitted_at=datetime.datetime(1970, 4, 13, 21, 8, 8,
-                                                                     tzinfo=UTC),
-                                      complete=False, complete_at=None, results=-1,
-                                      parent_buildid=None, parent_relationship=None,
-                                      bsid=bsdict['bsid']))
+        self.assertEqual(bsdict, {
+            "external_idstring": 'extid',
+            "reason": 'because',
+            "sourcestamps": [234],
+            "submitted_at": datetime.datetime(1970, 4, 13, 21, 8, 8, tzinfo=UTC),
+            "complete": False,
+            "complete_at": None,
+            "results": -1,
+            "parent_buildid": None,
+            "parent_relationship": None,
+            "bsid": bsdict['bsid']
+        })
 
     @defer.inlineCallbacks
     def do_test_getBuildsetProperties(self, buildsetid, rows, expected):
-        yield self.insertTestData(rows)
+        yield self.insert_test_data(rows)
         props = yield self.db.buildsets.getBuildsetProperties(buildsetid)
 
         self.assertEqual(props, expected)
@@ -128,7 +137,7 @@ class Tests(interfaces.InterfaceTests):
                                     property_value='["one", "fake1"]'),
             fakedb.BuildsetProperty(buildsetid=91, property_name='prop2',
                                     property_value='["two", "fake2"]'),
-        ], dict(prop1=("one", "fake1"), prop2=("two", "fake2")))
+        ], {"prop1": ('one', 'fake1'), "prop2": ('two', 'fake2')})
 
     def test_getBuildsetProperties_empty(self):
         return self.do_test_getBuildsetProperties(91, [
@@ -141,7 +150,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getBuildset_incomplete_zero(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Buildset(id=91, complete=0,
                             complete_at=0, results=-1, submitted_at=266761875,
                             external_idstring='extid', reason='rsn'),
@@ -150,18 +159,22 @@ class Tests(interfaces.InterfaceTests):
         bsdict = yield self.db.buildsets.getBuildset(91)
 
         validation.verifyDbDict(self, 'bsdict', bsdict)
-        self.assertEqual(bsdict, dict(external_idstring='extid',
-                                      reason='rsn', sourcestamps=[234],
-                                      submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                                     tzinfo=UTC),
-                                      complete=False,
-                                      complete_at=epoch2datetime(0), results=-1,
-                                      bsid=91,
-                                      parent_buildid=None, parent_relationship=None))
+        self.assertEqual(bsdict, {
+            "external_idstring": 'extid',
+            "reason": 'rsn',
+            "sourcestamps": [234],
+            "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 15, tzinfo=UTC),
+            "complete": False,
+            "complete_at": epoch2datetime(0),
+            "results": -1,
+            "bsid": 91,
+            "parent_buildid": None,
+            "parent_relationship": None
+        })
 
     @defer.inlineCallbacks
     def test_getBuildset_complete(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             fakedb.Buildset(id=91, complete=1,
                             complete_at=298297875, results=-1, submitted_at=266761875,
                             external_idstring='extid', reason='rsn'),
@@ -170,16 +183,18 @@ class Tests(interfaces.InterfaceTests):
         bsdict = yield self.db.buildsets.getBuildset(91)
 
         validation.verifyDbDict(self, 'bsdict', bsdict)
-        self.assertEqual(bsdict, dict(external_idstring='extid',
-                                      reason='rsn', sourcestamps=[234],
-                                      submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                                     tzinfo=UTC),
-                                      complete=True,
-                                      complete_at=datetime.datetime(1979, 6, 15, 12, 31, 15,
-                                                                    tzinfo=UTC),
-                                      results=-1,
-                                      bsid=91,
-                                      parent_buildid=None, parent_relationship=None))
+        self.assertEqual(bsdict, {
+            "external_idstring": 'extid',
+            "reason": 'rsn',
+            "sourcestamps": [234],
+            "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 15, tzinfo=UTC),
+            "complete": True,
+            "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 15, tzinfo=UTC),
+            "results": -1,
+            "bsid": 91,
+            "parent_buildid": None,
+            "parent_relationship": None
+        })
 
     @defer.inlineCallbacks
     def test_getBuildset_nosuch(self):
@@ -188,7 +203,7 @@ class Tests(interfaces.InterfaceTests):
         self.assertEqual(bsdict, None)
 
     def insert_test_getBuildsets_data(self):
-        return self.insertTestData([
+        return self.insert_test_data([
             fakedb.Buildset(id=91, complete=0,
                             complete_at=298297875, results=-1, submitted_at=266761875,
                             external_idstring='extid', reason='rsn1'),
@@ -216,20 +231,29 @@ class Tests(interfaces.InterfaceTests):
         for bsdict in bsdictlist:
             validation.verifyDbDict(self, 'bsdict', bsdict)
         self.assertEqual(sorted(bsdictlist, key=bsdictKey), sorted([
-            dict(external_idstring='extid', reason='rsn1', sourcestamps=[234],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 15,
-                                               tzinfo=UTC),
-                 complete=False, results=-1, bsid=91,
-                 parent_buildid=None, parent_relationship=None),
-            dict(external_idstring='extid', reason='rsn2', sourcestamps=[234],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 16,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 16,
-                                               tzinfo=UTC),
-                 complete=True, results=7, bsid=92,
-                 parent_buildid=None, parent_relationship=None),
+            {
+                "external_idstring": 'extid',
+                "reason": 'rsn1',
+                "sourcestamps": [234],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete": False,
+                "results": -1,
+                "bsid": 91,
+                "parent_buildid": None,
+                "parent_relationship": None
+            }, {
+                "external_idstring": 'extid',
+                "reason": 'rsn2',
+                "sourcestamps": [234],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete": True,
+                "results": 7,
+                "bsid": 92,
+                "parent_buildid": None,
+                "parent_relationship": None
+            },
         ], key=bsdictKey))
 
     @defer.inlineCallbacks
@@ -240,13 +264,18 @@ class Tests(interfaces.InterfaceTests):
         for bsdict in bsdictlist:
             validation.verifyDbDict(self, 'bsdict', bsdict)
         self.assertEqual(bsdictlist, [
-            dict(external_idstring='extid', reason='rsn2', sourcestamps=[234],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 16,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 16,
-                                               tzinfo=UTC),
-                 complete=True, results=7, bsid=92,
-                 parent_buildid=None, parent_relationship=None),
+            {
+                "external_idstring": 'extid',
+                "reason": 'rsn2',
+                "sourcestamps": [234],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete": True,
+                "results": 7,
+                "bsid": 92,
+                "parent_buildid": None,
+                "parent_relationship": None
+            },
         ])
 
     @defer.inlineCallbacks
@@ -257,13 +286,18 @@ class Tests(interfaces.InterfaceTests):
         for bsdict in bsdictlist:
             validation.verifyDbDict(self, 'bsdict', bsdict)
         self.assertEqual(bsdictlist, [
-            dict(external_idstring='extid', reason='rsn1', sourcestamps=[234],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 15,
-                                               tzinfo=UTC),
-                 complete=False, results=-1, bsid=91,
-                 parent_buildid=None, parent_relationship=None),
+            {
+                "external_idstring": 'extid',
+                "reason": 'rsn1',
+                "sourcestamps": [234],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete": False,
+                "results": -1,
+                "bsid": 91,
+                "parent_buildid": None,
+                "parent_relationship": None
+            },
         ])
 
     def test_completeBuildset_already_completed(self):
@@ -308,7 +342,7 @@ class Tests(interfaces.InterfaceTests):
             (92, 1, 298297876, 7)]))
 
     def insert_test_getRecentBuildsets_data(self):
-        return self.insertTestData([
+        return self.insert_test_data([
             fakedb.SourceStamp(id=91, branch='branch_a', repository='repo_a'),
 
             fakedb.Buildset(id=91, complete=0,
@@ -334,20 +368,29 @@ class Tests(interfaces.InterfaceTests):
                                                             repository='repo_a')
 
         self.assertEqual(bsdictlist, [
-            dict(external_idstring='extid', reason='rsn1', sourcestamps=[91],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 15,
-                                               tzinfo=UTC),
-                 complete=False, results=-1, bsid=91,
-                 parent_buildid=None, parent_relationship=None),
-            dict(external_idstring='extid', reason='rsn2', sourcestamps=[91],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 16,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 16,
-                                               tzinfo=UTC),
-                 complete=True, results=7, bsid=92,
-                 parent_buildid=None, parent_relationship=None)
+            {
+                "external_idstring": 'extid',
+                "reason": 'rsn1',
+                "sourcestamps": [91],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 15, tzinfo=UTC),
+                "complete": False,
+                "results": -1,
+                "bsid": 91,
+                "parent_buildid": None,
+                "parent_relationship": None
+            }, {
+                "external_idstring": 'extid',
+                "reason": 'rsn2',
+                "sourcestamps": [91],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete": True,
+                "results": 7,
+                "bsid": 92,
+                "parent_buildid": None,
+                "parent_relationship": None
+            }
         ])
 
     @defer.inlineCallbacks
@@ -358,13 +401,18 @@ class Tests(interfaces.InterfaceTests):
                                                             repository='repo_a')
 
         self.assertEqual(bsdictlist, [
-            dict(external_idstring='extid', reason='rsn2', sourcestamps=[91],
-                 submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 16,
-                                                tzinfo=UTC),
-                 complete_at=datetime.datetime(1979, 6, 15, 12, 31, 16,
-                                               tzinfo=UTC),
-                 complete=True, results=7, bsid=92,
-                 parent_buildid=None, parent_relationship=None),
+            {
+                "external_idstring": 'extid',
+                "reason": 'rsn2',
+                "sourcestamps": [91],
+                "submitted_at": datetime.datetime(1978, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete_at": datetime.datetime(1979, 6, 15, 12, 31, 16, tzinfo=UTC),
+                "complete": True,
+                "results": 7,
+                "bsid": 92,
+                "parent_buildid": None,
+                "parent_relationship": None
+            },
         ])
 
     @defer.inlineCallbacks
@@ -434,7 +482,7 @@ class RealTests(Tests):
 
     @defer.inlineCallbacks
     def test_addBuildset_bigger(self):
-        props = dict(prop=(['list'], 'test'))
+        props = {"prop": (['list'], 'test')}
         yield defer.succeed(None)
         xxx_todo_changeme1 = yield self.db.buildsets.addBuildset(
                                         sourcestamps=[234], reason='because',
@@ -507,7 +555,7 @@ class TestRealDB(db.TestCase,
             table_names=['patches', 'buildsets', 'buildset_properties',
                          'objects', 'buildrequests', 'sourcestamps',
                          'buildset_sourcestamps', 'builders',
-                         'builds', 'masters', 'workers'])
+                         'builds', 'masters', 'workers', "projects"])
 
         self.db.buildsets = buildsets.BuildsetsConnectorComponent(self.db)
         yield self.setUpTests()
@@ -529,7 +577,7 @@ class TestRealDB(db.TestCase,
             "put", mockedCachePut)
 
         # Setup a dummy set of properties to insert with the buildset.
-        props = dict(prop=(['list'], 'test'))
+        props = {"prop": (['list'], 'test')}
 
         # Now, call `addBuildset`, and verify that the above properties
         # were seed in the `getBuildsetProperties` cache.
