@@ -27,11 +27,12 @@ class BuildbotCreateEngineTest(unittest.TestCase):
     "Test the special case methods, without actually creating a db"
 
     # used several times below
-    mysql_kwargs = dict(
-        basedir='my-base-dir',
-        connect_args=dict(init_command='SET default_storage_engine=MyISAM'),
-        pool_recycle=3600)
-    sqlite_kwargs = dict(basedir='/my-base-dir', poolclass=NullPool)
+    mysql_kwargs = {
+        "basedir": 'my-base-dir',
+        "connect_args": {"init_command": 'SET default_storage_engine=MyISAM'},
+        "pool_recycle": 3600
+    }
+    sqlite_kwargs = {"basedir": '/my-base-dir', "poolclass": NullPool}
 
     # utility
 
@@ -46,7 +47,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_sqlite_pct_sub(self):
         u = url.make_url("sqlite:///%(basedir)s/x/state.sqlite")
-        kwargs = dict(basedir='/my-base-dir')
+        kwargs = {"basedir": '/my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_sqlite(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["sqlite:////my-base-dir/x/state.sqlite", 1,
@@ -67,30 +68,34 @@ class BuildbotCreateEngineTest(unittest.TestCase):
         exp_kwargs['basedir'] = basedir
 
         u = url.make_url(url_src)
-        kwargs = dict(basedir=basedir)
+        kwargs = {"basedir": basedir}
         u, kwargs, max_conns = enginestrategy.special_case_sqlite(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          [expected_url, 1, exp_kwargs])
 
     def test_sqlite_abspath(self):
         u = url.make_url("sqlite:////x/state.sqlite")
-        kwargs = dict(basedir='/my-base-dir')
+        kwargs = {"basedir": '/my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_sqlite(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["sqlite:////x/state.sqlite", 1, self.sqlite_kwargs])
 
     def test_sqlite_memory(self):
         u = url.make_url("sqlite://")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_sqlite(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
-                         ["sqlite://", 1,  # only one conn at a time
-                          dict(basedir='my-base-dir',
-                               connect_args=dict(check_same_thread=False))])
+            ["sqlite://", 1,  # only one conn at a time
+            {
+                "basedir": 'my-base-dir',
+                "connect_args": {"check_same_thread": False}
+            }
+            ]
+        )
 
     def test_mysql_simple(self):
         u = url.make_url("mysql://host/dbname")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql://host/dbname?charset=utf8&use_unicode=True", None,
@@ -98,7 +103,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_userport(self):
         u = url.make_url("mysql://user:pass@host:1234/dbname")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql://user:pass@host:1234/dbname?"
@@ -106,7 +111,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_local(self):
         u = url.make_url("mysql:///dbname")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql:///dbname?charset=utf8&use_unicode=True", None,
@@ -114,7 +119,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_args(self):
         u = url.make_url("mysql:///dbname?foo=bar")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql:///dbname?charset=utf8&foo=bar&use_unicode=True",
@@ -122,7 +127,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_max_idle(self):
         u = url.make_url("mysql:///dbname?max_idle=1234")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         exp = self.mysql_kwargs.copy()
         exp['pool_recycle'] = 1234
@@ -132,7 +137,7 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_good_charset(self):
         u = url.make_url("mysql:///dbname?charset=utf8")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql:///dbname?charset=utf8&use_unicode=True", None,
@@ -140,13 +145,13 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_bad_charset(self):
         u = url.make_url("mysql:///dbname?charset=ebcdic")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         with self.assertRaises(TypeError):
             enginestrategy.special_case_mysql(u, kwargs)
 
     def test_mysql_good_use_unicode(self):
         u = url.make_url("mysql:///dbname?use_unicode=True")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql:///dbname?charset=utf8&use_unicode=True", None,
@@ -154,17 +159,18 @@ class BuildbotCreateEngineTest(unittest.TestCase):
 
     def test_mysql_bad_use_unicode(self):
         u = url.make_url("mysql:///dbname?use_unicode=maybe")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         with self.assertRaises(TypeError):
             enginestrategy.special_case_mysql(u, kwargs)
 
     def test_mysql_storage_engine(self):
         u = url.make_url("mysql:///dbname?storage_engine=foo")
-        kwargs = dict(basedir='my-base-dir')
+        kwargs = {"basedir": 'my-base-dir'}
         u, kwargs, max_conns = enginestrategy.special_case_mysql(u, kwargs)
         exp = self.mysql_kwargs.copy()
-        exp['connect_args'] = dict(
-            init_command='SET default_storage_engine=foo')
+        exp['connect_args'] = {
+            "init_command": 'SET default_storage_engine=foo'
+        }
         self.assertEqual([str(u), max_conns, self.filter_kwargs(kwargs)],
                          ["mysql:///dbname?charset=utf8&use_unicode=True", None,
                           exp])
