@@ -52,33 +52,36 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_enable(self):
-        yield self.insertTestData([self.scheduler24, self.master13,
+        yield self.insert_test_data([self.scheduler24, self.master13,
                                    self.scheduler24master])
         sch = yield self.db.schedulers.getScheduler(24)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=24,
-            name='schname',
-            enabled=True,
-            masterid=13))
+        self.assertEqual(sch, {
+            "id": 24,
+            "name": 'schname',
+            "enabled": True,
+            "masterid": 13
+        })
 
         yield self.db.schedulers.enable(24, False)
         sch = yield self.db.schedulers.getScheduler(24)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=24,
-            name='schname',
-            enabled=False,
-            masterid=13))
+        self.assertEqual(sch, {
+            "id": 24,
+            "name": 'schname',
+            "enabled": False,
+            "masterid": 13
+        })
 
         yield self.db.schedulers.enable(24, True)
         sch = yield self.db.schedulers.getScheduler(24)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=24,
-            name='schname',
-            enabled=True,
-            masterid=13))
+        self.assertEqual(sch, {
+            "id": 24,
+            "name": 'schname',
+            "enabled": True,
+            "masterid": 13
+        })
 
     def test_signature_classifyChanges(self):
         @self.assertArgSpecMatches(self.db.schedulers.classifyChanges)
@@ -87,7 +90,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_classifyChanges(self):
-        yield self.insertTestData([self.ss92, self.change3, self.change4,
+        yield self.insert_test_data([self.ss92, self.change3, self.change4,
                                    self.scheduler24])
         yield self.db.schedulers.classifyChanges(24,
                                                  {3: False, 4: True})
@@ -99,7 +102,7 @@ class Tests(interfaces.InterfaceTests):
         # test reclassifying changes, which may happen during some timing
         # conditions.  It's important that this test uses multiple changes,
         # only one of which already exists
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.ss92,
             self.change3,
             self.change4,
@@ -121,7 +124,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_flushChangeClassifications(self):
-        yield self.insertTestData([self.ss92, self.change3, self.change4,
+        yield self.insert_test_data([self.ss92, self.change3, self.change4,
                                    self.change5, self.scheduler24])
         yield self.addClassifications(24,
                                       (3, 1), (4, 0), (5, 1))
@@ -133,7 +136,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_flushChangeClassifications_less_than(self):
-        yield self.insertTestData([self.ss92, self.change3,
+        yield self.insert_test_data([self.ss92, self.change3,
                                    self.change4, self.change5, self.scheduler24])
         yield self.addClassifications(24,
                                       (3, 1), (4, 0), (5, 1))
@@ -149,7 +152,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getChangeClassifications(self):
-        yield self.insertTestData([self.ss92, self.change3, self.change4,
+        yield self.insert_test_data([self.ss92, self.change3, self.change4,
                                    self.change5, self.change6, self.scheduler24])
         yield self.addClassifications(24,
                                       (3, 1), (4, 0), (5, 1), (6, 1))
@@ -158,7 +161,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getChangeClassifications_branch(self):
-        yield self.insertTestData([self.ss92, self.change3, self.change4,
+        yield self.insert_test_data([self.ss92, self.change3, self.change4,
                                    self.change5, self.change6, self.scheduler24])
         yield self.addClassifications(24,
                                       (3, 1), (4, 0), (5, 1), (6, 1))
@@ -190,14 +193,14 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_fresh(self):
-        yield self.insertTestData([self.scheduler24, self.master13])
+        yield self.insert_test_data([self.scheduler24, self.master13])
         yield self.db.schedulers.setSchedulerMaster(24, 13)
         sch = yield self.db.schedulers.getScheduler(24)
         self.assertEqual(sch['masterid'], 13)
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_inactive_but_linked(self):
-        d = self.insertTestData([
+        d = self.insert_test_data([
             self.master13,
             self.scheduler25, self.master14, self.scheduler25master,
         ])
@@ -207,14 +210,14 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_inactive_but_linked_to_this_master(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler25, self.master14, self.scheduler25master,
         ])
         yield self.db.schedulers.setSchedulerMaster(25, 14)
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_active(self):
-        d = self.insertTestData([
+        d = self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
         ])
         d.addCallback(lambda _:
@@ -223,7 +226,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_None(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler25, self.master14, self.scheduler25master,
         ])
         yield self.db.schedulers.setSchedulerMaster(25, None)
@@ -232,7 +235,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_setSchedulerMaster_None_unowned(self):
-        yield self.insertTestData([self.scheduler25])
+        yield self.insert_test_data([self.scheduler25])
         yield self.db.schedulers.setSchedulerMaster(25, None)
         sch = yield self.db.schedulers.getScheduler(25)
         self.assertEqual(sch['masterid'], None)
@@ -244,14 +247,15 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getScheduler(self):
-        yield self.insertTestData([self.scheduler24])
+        yield self.insert_test_data([self.scheduler24])
         sch = yield self.db.schedulers.getScheduler(24)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=24,
-            name='schname',
-            enabled=True,
-            masterid=None))
+        self.assertEqual(sch, {
+            "id": 24,
+            "name": 'schname',
+            "enabled": True,
+            "masterid": None
+        })
 
     @defer.inlineCallbacks
     def test_getScheduler_missing(self):
@@ -260,27 +264,29 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getScheduler_active(self):
-        yield self.insertTestData([self.scheduler24, self.master13,
+        yield self.insert_test_data([self.scheduler24, self.master13,
                                    self.scheduler24master])
         sch = yield self.db.schedulers.getScheduler(24)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=24,
-            name='schname',
-            enabled=True,
-            masterid=13))
+        self.assertEqual(sch, {
+            "id": 24,
+            "name": 'schname',
+            "enabled": True,
+            "masterid": 13
+        })
 
     @defer.inlineCallbacks
     def test_getScheduler_inactive_but_linked(self):
-        yield self.insertTestData([self.scheduler25, self.master14,
+        yield self.insert_test_data([self.scheduler25, self.master14,
                                    self.scheduler25master])
         sch = yield self.db.schedulers.getScheduler(25)
         validation.verifyDbDict(self, 'schedulerdict', sch)
-        self.assertEqual(sch, dict(
-            id=25,
-            name='schname2',
-            enabled=True,
-            masterid=14))  # row exists, but marked inactive
+        self.assertEqual(sch, {
+            "id": 25,
+            "name": 'schname2',
+            "enabled": True,
+            "masterid": 14
+        })  # row exists, but marked inactive
 
     def test_signature_getSchedulers(self):
         @self.assertArgSpecMatches(self.db.schedulers.getSchedulers)
@@ -289,7 +295,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getSchedulers(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25,
         ])
@@ -303,13 +309,13 @@ class Tests(interfaces.InterfaceTests):
             validation.verifyDbDict(self, 'schedulerdict', sch)
 
         self.assertEqual(sorted(schlist, key=schKey), sorted([
-            dict(id=24, name='schname', enabled=True, masterid=13),
-            dict(id=25, name='schname2', enabled=True, masterid=None),
+            {"id": 24, "name": 'schname', "enabled": True, "masterid": 13},
+            {"id": 25, "name": 'schname2', "enabled": True, "masterid": None},
         ], key=schKey))
 
     @defer.inlineCallbacks
     def test_getSchedulers_masterid(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25,
         ])
@@ -319,12 +325,12 @@ class Tests(interfaces.InterfaceTests):
             validation.verifyDbDict(self, 'schedulerdict', sch)
 
         self.assertEqual(sorted(schlist), sorted([
-            dict(id=24, name='schname', enabled=True, masterid=13),
+            {"id": 24, "name": 'schname', "enabled": True, "masterid": 13},
         ]))
 
     @defer.inlineCallbacks
     def test_getSchedulers_active(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25
         ])
@@ -334,12 +340,12 @@ class Tests(interfaces.InterfaceTests):
             validation.verifyDbDict(self, 'schedulerdict', sch)
 
         self.assertEqual(sorted(schlist), sorted([
-            dict(id=24, name='schname', enabled=True, masterid=13),
+            {"id": 24, "name": 'schname', "enabled": True, "masterid": 13},
         ]))
 
     @defer.inlineCallbacks
     def test_getSchedulers_active_masterid(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25
         ])
@@ -350,7 +356,7 @@ class Tests(interfaces.InterfaceTests):
             validation.verifyDbDict(self, 'schedulerdict', sch)
 
         self.assertEqual(sorted(schlist), sorted([
-            dict(id=24, name='schname', enabled=True, masterid=13),
+            {"id": 24, "name": 'schname', "enabled": True, "masterid": 13},
         ]))
 
         schlist = yield self.db.schedulers.getSchedulers(
@@ -363,7 +369,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getSchedulers_inactive(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25
         ])
@@ -373,12 +379,12 @@ class Tests(interfaces.InterfaceTests):
             validation.verifyDbDict(self, 'schedulerdict', sch)
 
         self.assertEqual(sorted(schlist), sorted([
-            dict(id=25, name='schname2', enabled=True, masterid=None),
+            {"id": 25, "name": 'schname2', "enabled": True, "masterid": None},
         ]))
 
     @defer.inlineCallbacks
     def test_getSchedulers_inactive_masterid(self):
-        yield self.insertTestData([
+        yield self.insert_test_data([
             self.scheduler24, self.master13, self.scheduler24master,
             self.scheduler25
         ])
@@ -439,6 +445,6 @@ class TestRealDB(db.TestCase,
         def thd(conn):
             q = self.db.model.scheduler_changes.insert()
             conn.execute(q, [
-                dict(changeid=c[0], schedulerid=schedulerid, important=c[1])
+                {"changeid": c[0], "schedulerid": schedulerid, "important": c[1]}
                 for c in classifications])
         yield self.db.pool.do(thd)
