@@ -119,9 +119,14 @@ class Tests(interfaces.InterfaceTests):
         def deconfigureAllWorkersForMaster(self, masterid):
             pass
 
-    def test_signature_setWorkerState(self):
-        @self.assertArgSpecMatches(self.db.workers.setWorkerState)
-        def setWorkerState(self, workerid, paused, graceful):
+    def test_signature_set_worker_paused(self):
+        @self.assertArgSpecMatches(self.db.workers.set_worker_paused)
+        def set_worker_paused(self, workerid, paused, pause_reason=None):
+            pass
+
+    def test_signature_set_worker_graceful(self):
+        @self.assertArgSpecMatches(self.db.workers.set_worker_graceful)
+        def set_worker_graceful(self, workerid, graceful):
             pass
 
     @defer.inlineCallbacks
@@ -133,34 +138,41 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_findWorkerId_existing(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         id = yield self.db.workers.findWorkerId(name="one")
         self.assertEqual(id, 31)
 
     @defer.inlineCallbacks
     def test_getWorker_no_such(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         workerdict = yield self.db.workers.getWorker(workerid=99)
         self.assertEqual(workerdict, None)
 
     @defer.inlineCallbacks
     def test_getWorker_by_name_no_such(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         workerdict = yield self.db.workers.getWorker(name='NOSUCH')
         self.assertEqual(workerdict, None)
 
     @defer.inlineCallbacks
     def test_getWorker_not_configured(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         workerdict = yield self.db.workers.getWorker(workerid=30)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, connected_to=[], configured_on=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "connected_to": [],
+            "configured_on": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_connected_not_configured(self):
-        yield self.insertTestData(self.baseRows + [
+        yield self.insert_test_data(self.baseRows + [
             # the worker is connected to this master, but not configured.
             # weird, but the DB should represent it.
             fakedb.Worker(id=32, name='two'),
@@ -168,13 +180,20 @@ class Tests(interfaces.InterfaceTests):
         ])
         workerdict = yield self.db.workers.getWorker(workerid=32)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=32, name='two', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, connected_to=[11], configured_on=[]))
+        self.assertEqual(workerdict, {
+            "id": 32,
+            "name": 'two',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "connected_to": [11],
+            "configured_on": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_multiple_connections(self):
-        yield self.insertTestData(self.baseRows + [
+        yield self.insert_test_data(self.baseRows + [
             # the worker is connected to two masters at once.
             # weird, but the DB should represent it.
             fakedb.Worker(id=32, name='two'),
@@ -188,150 +207,259 @@ class Tests(interfaces.InterfaceTests):
         workerdict = yield self.db.workers.getWorker(workerid=32)
         validation.verifyDbDict(self, 'workerdict', workerdict)
         self.assertEqual(workerdict,
-                         dict(id=32, name='two', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, connected_to=[10, 11],
-                              configured_on=[
-                                  {'builderid': 20, 'masterid': 10},
-                                  {'builderid': 20, 'masterid': 11},
-                              ]))
+            {
+                "id": 32,
+                "name": 'two',
+                "workerinfo": {'a': 'b'},
+                "paused": False,
+                "pause_reason": None,
+                "graceful": False,
+                "connected_to": [10, 11],
+                "configured_on": [
+                    {'builderid': 20, 'masterid': 10},
+                    {'builderid': 20, 'masterid': 11},
+                ]
+            }
+        )
 
     @defer.inlineCallbacks
     def test_getWorker_by_name_not_configured(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         workerdict = yield self.db.workers.getWorker(name='zero')
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, connected_to=[], configured_on=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "connected_to": [],
+            "configured_on": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_not_connected(self):
-        yield self.insertTestData(self.baseRows + [
+        yield self.insert_test_data(self.baseRows + [
             fakedb.BuilderMaster(id=12, builderid=20, masterid=10),
             fakedb.ConfiguredWorker(workerid=30, buildermasterid=12),
         ])
         workerdict = yield self.db.workers.getWorker(workerid=30)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=[{'masterid': 10, 'builderid': 20}],
-                              connected_to=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": [
+                {'masterid': 10, 'builderid': 20}
+            ],
+            "connected_to": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_connected(self):
-        yield self.insertTestData(self.baseRows + [
+        yield self.insert_test_data(self.baseRows + [
             fakedb.BuilderMaster(id=12, builderid=20, masterid=10),
             fakedb.ConfiguredWorker(workerid=30, buildermasterid=12),
             fakedb.ConnectedWorker(workerid=30, masterid=10),
         ])
         workerdict = yield self.db.workers.getWorker(workerid=30)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=[{'masterid': 10, 'builderid': 20}],
-                              connected_to=[10]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": [
+                {'masterid': 10, 'builderid': 20}
+            ],
+            "connected_to": [10]
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_with_multiple_masters(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdict = yield self.db.workers.getWorker(workerid=30)
         validation.verifyDbDict(self, 'workerdict', workerdict)
         workerdict['configured_on'] = sorted(
             workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=sorted([
-                                                  {'masterid': 10, 'builderid': 20},
-                                                  {'masterid': 10, 'builderid': 21},
-                                                  {'masterid': 11, 'builderid': 20},
-                              ], key=configuredOnKey), connected_to=[10]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": sorted([
+                {'masterid': 10, 'builderid': 20},
+                {'masterid': 10, 'builderid': 21},
+                {'masterid': 11, 'builderid': 20},
+            ], key=configuredOnKey),
+            "connected_to": [10]
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_with_multiple_masters_builderid(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdict = yield self.db.workers.getWorker(workerid=30, builderid=20)
         validation.verifyDbDict(self, 'workerdict', workerdict)
         workerdict['configured_on'] = sorted(
             workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=sorted([
-                                                  {'masterid': 10, 'builderid': 20},
-                                                  {'masterid': 11, 'builderid': 20},
-                              ], key=configuredOnKey), connected_to=[10]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": sorted([
+                {'masterid': 10, 'builderid': 20},
+                {'masterid': 11, 'builderid': 20},
+            ], key=configuredOnKey),
+            "connected_to": [10]
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_with_multiple_masters_masterid(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdict = yield self.db.workers.getWorker(workerid=30, masterid=11)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=[{'masterid': 11, 'builderid': 20}, ],
-                              connected_to=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": [
+                {'masterid': 11, 'builderid': 20},
+            ],
+            "connected_to": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_with_multiple_masters_builderid_masterid(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdict = yield self.db.workers.getWorker(workerid=30,
                                                      builderid=20, masterid=11)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=[{'masterid': 11, 'builderid': 20}, ],
-                              connected_to=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": [
+                {'masterid': 11, 'builderid': 20},
+            ],
+            "connected_to": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorker_by_name_with_multiple_masters_builderid_masterid(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdict = yield self.db.workers.getWorker(name='zero',
                                                      builderid=20, masterid=11)
         validation.verifyDbDict(self, 'workerdict', workerdict)
-        self.assertEqual(workerdict,
-                         dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False,
-                              graceful=False, configured_on=[{'masterid': 11, 'builderid': 20}, ],
-                              connected_to=[]))
+        self.assertEqual(workerdict, {
+            "id": 30,
+            "name": 'zero',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": False,
+            "configured_on": [
+                {'masterid': 11, 'builderid': 20},
+            ],
+            "connected_to": []
+        })
 
     @defer.inlineCallbacks
     def test_getWorkers_no_config(self):
-        yield self.insertTestData(self.baseRows)
+        yield self.insert_test_data(self.baseRows)
         workerdicts = yield self.db.workers.getWorkers()
 
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
 
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=[], connected_to=[]),
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=[], connected_to=[]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 30,
+                        "name": 'zero',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": [],
+                        "connected_to": []
+                    }, {
+                        "id": 31,
+                        "name": 'one',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": [],
+                        "connected_to": []
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_with_config(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers()
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = sorted(
                 workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 10, 'builderid': 20},
-                     {'masterid': 10, 'builderid': 21},
-                     {'masterid': 11, 'builderid': 20},
-                 ], key=configuredOnKey), connected_to=[10]),
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 11, 'builderid': 20},
-                     {'masterid': 11, 'builderid': 22},
-                 ], key=configuredOnKey), connected_to=[11]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 30,
+                        "name": 'zero',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                            {'masterid': 10, 'builderid': 20},
+                            {'masterid': 10, 'builderid': 21},
+                            {'masterid': 11, 'builderid': 20},
+                        ], key=configuredOnKey),
+                        "connected_to": [10]
+                    }, {
+                        "id": 31,
+                        "name": 'one',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                            {'masterid': 11, 'builderid': 20},
+                            {'masterid': 11, 'builderid': 22},
+                        ], key=configuredOnKey),
+                        "connected_to": [11]
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_empty(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers(masterid=11, builderid=21)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
@@ -341,107 +469,188 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getWorkers_with_config_builderid(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers(builderid=20)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = sorted(
                 workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 10, 'builderid': 20},
-                     {'masterid': 11, 'builderid': 20},
-                 ], key=configuredOnKey), connected_to=[10]),
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 11, 'builderid': 20},
-                 ], key=configuredOnKey), connected_to=[11]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 30,
+                        "name": 'zero',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                            {'masterid': 10, 'builderid': 20},
+                            {'masterid': 11, 'builderid': 20},
+                        ], key=configuredOnKey),
+                        "connected_to": [10]
+                    }, {
+                        "id": 31,
+                        "name": 'one',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                             {'masterid': 11, 'builderid': 20},
+                        ], key=configuredOnKey),
+                        "connected_to": [11]
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_with_config_masterid_10(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers(masterid=10)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = sorted(
                 workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 10, 'builderid': 20},
-                     {'masterid': 10, 'builderid': 21},
-                 ], key=configuredOnKey), connected_to=[10]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 30,
+                        "name": 'zero',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                            {'masterid': 10, 'builderid': 20},
+                            {'masterid': 10, 'builderid': 21},
+                        ], key=configuredOnKey),
+                        "connected_to": [10]
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_with_config_masterid_11(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers(masterid=11)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = sorted(
                 workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=30, name='zero', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 11, 'builderid': 20},
-                 ], key=configuredOnKey), connected_to=[]),
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 11, 'builderid': 20},
-                     {'masterid': 11, 'builderid': 22},
-                 ], key=configuredOnKey), connected_to=[11]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 30,
+                        "name": 'zero',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                             {'masterid': 11, 'builderid': 20},
+                        ], key=configuredOnKey),
+                        "connected_to": []
+                    },
+                    {
+                        "id": 31,
+                        "name": 'one',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([
+                            {'masterid': 11, 'builderid': 20},
+                            {'masterid': 11, 'builderid': 22},
+                        ], key=configuredOnKey),
+                        "connected_to": [11]
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_with_config_masterid_11_builderid_22(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
         workerdicts = yield self.db.workers.getWorkers(
             masterid=11, builderid=22)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = sorted(
                 workerdict['configured_on'], key=configuredOnKey)
-        self.assertEqual(sorted(workerdicts, key=workerKey), sorted([
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=False,
-                 configured_on=sorted([
-                     {'masterid': 11, 'builderid': 22},
-                 ], key=configuredOnKey), connected_to=[11]),
-        ], key=workerKey))
+        self.assertEqual(
+            sorted(workerdicts, key=workerKey),
+            sorted(
+                [
+                    {
+                        "id": 31,
+                        "name": 'one',
+                        "workerinfo": {'a': 'b'},
+                        "paused": False,
+                        "pause_reason": None,
+                        "graceful": False,
+                        "configured_on": sorted([{'masterid': 11, 'builderid': 22}, ],
+                            key=configuredOnKey),
+                        "connected_to": [11]
+                    },
+                ], key=workerKey
+            )
+        )
 
     @defer.inlineCallbacks
     def test_getWorkers_with_paused(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
-        yield self.db.workers.setWorkerState(31, paused=True, graceful=False)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
+        yield self.db.workers.set_worker_paused(31, paused=True, pause_reason="reason")
+        yield self.db.workers.set_worker_graceful(31, graceful=False)
         workerdicts = yield self.db.workers.getWorkers(
             paused=True)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = []
         self.assertEqual(workerdicts, [
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=True, graceful=False,
-                 configured_on=[], connected_to=[11]),
-        ])
+        {
+            "id": 31,
+            "name": 'one',
+            "workerinfo": {'a': 'b'},
+            "paused": True,
+            "pause_reason": "reason",
+            "graceful": False,
+            "configured_on": [],
+            "connected_to": [11]
+        }, ])
 
     @defer.inlineCallbacks
     def test_getWorkers_with_graceful(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
-        yield self.db.workers.setWorkerState(31, paused=False, graceful=True)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
+        yield self.db.workers.set_worker_paused(31, paused=False)
+        yield self.db.workers.set_worker_graceful(31, graceful=True)
         workerdicts = yield self.db.workers.getWorkers(
             graceful=True)
         for workerdict in workerdicts:
             validation.verifyDbDict(self, 'workerdict', workerdict)
             workerdict['configured_on'] = []
-        self.assertEqual(workerdicts, [
-            dict(id=31, name='one', workerinfo={'a': 'b'}, paused=False, graceful=True,
-                 configured_on=[], connected_to=[11]),
-        ])
+        self.assertEqual(workerdicts, [{
+            "id": 31,
+            "name": 'one',
+            "workerinfo": {'a': 'b'},
+            "paused": False,
+            "pause_reason": None,
+            "graceful": True,
+            "configured_on": [],
+            "connected_to": [11]
+        }, ])
 
     @defer.inlineCallbacks
     def test_workerConnected_existing(self):
-        yield self.insertTestData(self.baseRows + self.worker1_rows)
+        yield self.insert_test_data(self.baseRows + self.worker1_rows)
 
         NEW_INFO = {'other': [1, 2, 3]}
 
@@ -454,13 +663,15 @@ class Tests(interfaces.InterfaceTests):
             'name': self.W1_NAME,
             'workerinfo': NEW_INFO,
             'paused': False,
+            "pause_reason": None,
             'graceful': False,
             'configured_on': [],
-            'connected_to': [11]})
+            'connected_to': [11]
+        })
 
     @defer.inlineCallbacks
     def test_workerConnected_already_connected(self):
-        yield self.insertTestData(self.baseRows + self.worker1_rows + [
+        yield self.insert_test_data(self.baseRows + self.worker1_rows + [
             fakedb.ConnectedWorker(id=888,
                                    workerid=self.W1_ID, masterid=11),
         ])
@@ -472,7 +683,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerDisconnected(self):
-        yield self.insertTestData(self.baseRows + self.worker1_rows + [
+        yield self.insert_test_data(self.baseRows + self.worker1_rows + [
             fakedb.ConnectedWorker(id=888,
                                    workerid=self.W1_ID, masterid=10),
             fakedb.ConnectedWorker(id=889,
@@ -486,7 +697,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerDisconnected_already_disconnected(self):
-        yield self.insertTestData(self.baseRows + self.worker1_rows)
+        yield self.insert_test_data(self.baseRows + self.worker1_rows)
         yield self.db.workers.workerDisconnected(
             workerid=self.W1_ID, masterid=11)
 
@@ -494,11 +705,10 @@ class Tests(interfaces.InterfaceTests):
         self.assertEqual(w['connected_to'], [])
 
     @defer.inlineCallbacks
-    def test_setWorkerState_existing(self):
-        yield self.insertTestData(self.baseRows + self.worker1_rows)
+    def test_set_worker_paused_existing(self):
+        yield self.insert_test_data(self.baseRows + self.worker1_rows)
 
-        yield self.db.workers.setWorkerState(
-            workerid=self.W1_ID, paused=False, graceful=True)
+        yield self.db.workers.set_worker_paused(self.W1_ID, False, None)
 
         w = yield self.db.workers.getWorker(self.W1_ID)
         self.assertEqual(w, {
@@ -506,12 +716,13 @@ class Tests(interfaces.InterfaceTests):
             'name': self.W1_NAME,
             'workerinfo': self.W1_INFO,
             'paused': False,
-            'graceful': True,
+            "pause_reason": None,
+            'graceful': False,
             'configured_on': [],
-            'connected_to': []})
+            'connected_to': []
+        })
 
-        yield self.db.workers.setWorkerState(
-            workerid=self.W1_ID, paused=True, graceful=False)
+        yield self.db.workers.set_worker_paused(self.W1_ID, True, "reason")
 
         w = yield self.db.workers.getWorker(self.W1_ID)
         self.assertEqual(w, {
@@ -519,13 +730,47 @@ class Tests(interfaces.InterfaceTests):
             'name': self.W1_NAME,
             'workerinfo': self.W1_INFO,
             'paused': True,
+            "pause_reason": "reason",
             'graceful': False,
             'configured_on': [],
-            'connected_to': []})
+            'connected_to': []
+        })
+
+    @defer.inlineCallbacks
+    def test_set_worker_graceful_existing(self):
+        yield self.insert_test_data(self.baseRows + self.worker1_rows)
+
+        yield self.db.workers.set_worker_graceful(self.W1_ID, False)
+
+        w = yield self.db.workers.getWorker(self.W1_ID)
+        self.assertEqual(w, {
+            'id': self.W1_ID,
+            'name': self.W1_NAME,
+            'workerinfo': self.W1_INFO,
+            'paused': False,
+            "pause_reason": None,
+            'graceful': False,
+            'configured_on': [],
+            'connected_to': []
+        })
+
+        yield self.db.workers.set_worker_graceful(self.W1_ID, True)
+
+        w = yield self.db.workers.getWorker(self.W1_ID)
+        self.assertEqual(w, {
+            'id': self.W1_ID,
+            'name': self.W1_NAME,
+            'workerinfo': self.W1_INFO,
+            'paused': False,
+            "pause_reason": None,
+            'graceful': True,
+            'configured_on': [],
+            'connected_to': []
+        })
 
     @defer.inlineCallbacks
     def test_workerConfigured(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove builder 21, and add 22
         yield self.db.workers.deconfigureAllWorkersForMaster(masterid=10)
@@ -541,7 +786,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerConfiguredTwice(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove builder 21, and add 22
         yield self.db.workers.deconfigureAllWorkersForMaster(masterid=10)
@@ -564,7 +809,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerReConfigured(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove builder 21, and add 22
         yield self.db.workers.workerConfigured(
@@ -580,7 +825,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerReConfigured_should_not_affect_other_worker(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove all the builders in master 11
         yield self.db.workers.workerConfigured(
@@ -603,7 +848,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_workerUnconfigured(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove all builders from master 10
         yield self.db.workers.workerConfigured(
@@ -617,7 +862,7 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_nothingConfigured(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         # should remove builder 21, and add 22
         yield self.db.workers.deconfigureAllWorkersForMaster(masterid=10)
@@ -626,12 +871,11 @@ class Tests(interfaces.InterfaceTests):
 
         # should only keep builder for master 11
         w = yield self.db.workers.getWorker(30)
-        self.assertEqual(sorted(w['configured_on']), sorted([
-            {'builderid': 20, 'masterid': 11}]))
+        self.assertEqual(sorted(w['configured_on']), sorted([{'builderid': 20, 'masterid': 11}]))
 
     @defer.inlineCallbacks
     def test_deconfiguredAllWorkers(self):
-        yield self.insertTestData(self.baseRows + self.multipleMasters)
+        yield self.insert_test_data(self.baseRows + self.multipleMasters)
 
         res = yield self.db.workers.getWorkers(masterid=11)
         self.assertEqual(len(res), 2)
@@ -663,7 +907,7 @@ class TestRealDB(unittest.TestCase,
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpConnectorComponent(
-            table_names=['workers', 'masters', 'builders',
+            table_names=['workers', 'masters', 'projects', 'builders',
                          'builder_masters', 'connected_workers',
                          'configured_workers'])
 
@@ -682,7 +926,7 @@ class TestRealDB(unittest.TestCase,
                 id=n + 3000, workerid=50 + n, buildermasterid=1000)
             for n in range(1000)
         ]
-        yield self.insertTestData(self.baseRows + manyWorkers)
+        yield self.insert_test_data(self.baseRows + manyWorkers)
 
         # should successfully remove all ConfiguredWorker rows
         with self.assertNoMaxVariables():
@@ -707,7 +951,7 @@ class TestRealDB(unittest.TestCase,
                 id=n + 3000, workerid=50 + n, buildermasterid=int(1000 + n / 2))
             for n in range(2000)
         ]
-        yield self.insertTestData(self.baseRows + manyWorkers)
+        yield self.insert_test_data(self.baseRows + manyWorkers)
 
         # should successfully remove all ConfiguredWorker rows
         with self.assertNoMaxVariables():
