@@ -14,8 +14,7 @@
 # Copyright Buildbot Team Members
 
 from copy import deepcopy
-
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.trial import unittest
@@ -929,8 +928,10 @@ class TestProperties(unittest.TestCase):
         self.props.setProperty("msi_filename", "product.msi", 'packager')
         self.props.setProperty("dmg_filename", "product.dmg", 'packager')
 
-        self.assertEqual(self.props.asDict(), dict(msi_filename=('product.msi', 'packager'),
-                                                   dmg_filename=('product.dmg', 'packager')))
+        self.assertEqual(self.props.asDict(), {
+            "msi_filename": ('product.msi', 'packager'),
+            "dmg_filename": ('product.dmg', 'packager')
+        })
 
     def testUpdate(self):
         self.props.setProperty("x", 24, "old")
