@@ -73,10 +73,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'INPROGRESS',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
@@ -87,10 +87,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'SUCCESSFUL',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
@@ -101,10 +101,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'FAILED',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
@@ -129,10 +129,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'SUCCESSFUL',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
@@ -148,10 +148,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'SUCCESSFUL',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=200)
 
@@ -185,10 +185,10 @@ class TestBitbucketStatusPush(TestReactorMixin, unittest.TestCase, ConfigErrorsM
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'INPROGRESS',
-                'key': 'Builder0',
+                'key': '0550a051225ac4ea91a92c9c94d41dfe6fa9f428',  # sha1("Builder0")
                 'name': 'Builder0',
                 'description': '',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=404,
             content_json={
@@ -264,10 +264,10 @@ class TestBitbucketStatusPushProperties(TestReactorMixin, unittest.TestCase,
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'INPROGRESS',
-                'key': 'Builder0/0',
+                'key': '84f9e75c46896d56da4fd75e096d24ec62f76f33',  # sha1("Builder0/0")
                 'name': 'Builder0-0',
                 'description': 'not finished build',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
@@ -278,10 +278,10 @@ class TestBitbucketStatusPushProperties(TestReactorMixin, unittest.TestCase,
             '/user/repo/commit/d34db33fd43db33f/statuses/build',
             json={
                 'state': 'SUCCESSFUL',
-                'key': 'Builder0/0',
+                'key': '84f9e75c46896d56da4fd75e096d24ec62f76f33',  # sha1("Builder0/0")
                 'name': 'Builder0-0',
                 'description': 'Build succeeded!',
-                'url': 'http://localhost:8080/#builders/79/builds/0',
+                'url': 'http://localhost:8080/#/builders/79/builds/0',
             },
             code=201)
 
