@@ -15,8 +15,7 @@
 
 
 import sys
-
-import mock
+from unittest import mock
 
 from twisted.application import internet
 from twisted.internet import defer
@@ -333,7 +332,7 @@ class TestIrcStatusBot(unittest.TestCase):
 
     def test_signedOn(self):
         b = self.makeBot('nick', 'pass',
-                         ['#ch1', dict(channel='#ch2', password='sekrits')],
+                         ['#ch1', {"channel": '#ch2', "password": 'sekrits'}],
                          ['jimmy', 'bobby'], False)
         events = []
 
