@@ -44,7 +44,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
 
     def setupDb(self):
         self.db = self.master.db
-        self.db.insertTestData([
+        self.db.insert_test_data([
             fakedb.Master(id=92),
             fakedb.Worker(id=13, name='wrk'),
             fakedb.Buildset(id=98, results=SUCCESS, reason="testReason1"),
@@ -77,7 +77,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
             fakedb.SourceStamp(id=235, patchid=99),
         ])
         for _id in (20, 21):
-            self.db.insertTestData([
+            self.db.insert_test_data([
                 fakedb.BuildProperty(
                     buildid=_id, name="workername", value="wrk"),
                 fakedb.BuildProperty(
@@ -153,7 +153,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
         build1 = res['builds'][0]
         self.assertEqual(build1['steps'][0]['logs'][0]['content']['content'], self.LOGCONTENT)
         self.assertEqual(build1['steps'][0]['logs'][0]['url'],
-                         'http://localhost:8080/#builders/80/builds/2/steps/29/logs/stdio')
+                         'http://localhost:8080/#/builders/80/builds/2/steps/29/logs/stdio')
 
     @defer.inlineCallbacks
     def test_get_details_for_buildset_all(self):
@@ -167,6 +167,9 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                 'builder': {
                     'builderid': 80,
                     'description': None,
+                    'description_format': None,
+                    'description_html': None,
+                    'projectid': None,
                     'masterids': [],
                     'name': 'Builder1',
                     'tags': []
@@ -226,6 +229,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'complete': False,
                     'complete_at': None,
                     'hidden': False,
+                    "locks_acquired_at": None,
                     'logs': [{
                         'complete': False,
                         'content': {
@@ -239,7 +243,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                         'slug': 'stdio',
                         'stepid': 120,
                         'type': 's',
-                        'url': 'http://localhost:8080/#builders/80/builds/2/steps/29/logs/stdio'
+                        'url': 'http://localhost:8080/#/builders/80/builds/2/steps/29/logs/stdio'
                     }],
                     'name': 'step1',
                     'number': 29,
@@ -253,6 +257,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'complete': False,
                     'complete_at': None,
                     'hidden': False,
+                    "locks_acquired_at": None,
                     'logs': [],
                     'name': 'step2',
                     'number': 29,
@@ -262,12 +267,15 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'stepid': 220,
                     'urls': []
                 }],
-                'url': 'http://localhost:8080/#builders/80/builds/2',
+                'url': 'http://localhost:8080/#/builders/80/builds/2',
                 'workerid': 13
             }, {
                 'builder': {
                     'builderid': 80,
                     'description': None,
+                    'description_format': None,
+                    'description_html': None,
+                    'projectid': None,
                     'masterids': [],
                     'name': 'Builder1',
                     'tags': []
@@ -327,6 +335,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'complete': False,
                     'complete_at': None,
                     'hidden': False,
+                    "locks_acquired_at": None,
                     'logs': [{
                         'complete': False,
                         'content': {'content': 'line zero\nline 1\n',
@@ -338,7 +347,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                         'slug': 'stdio',
                         'stepid': 121,
                         'type': 's',
-                        'url': 'http://localhost:8080/#builders/80/builds/3/steps/29/logs/stdio'
+                        'url': 'http://localhost:8080/#/builders/80/builds/3/steps/29/logs/stdio'
                     }],
                     'name': 'step1',
                     'number': 29,
@@ -352,6 +361,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'complete': False,
                     'complete_at': None,
                     'hidden': False,
+                    "locks_acquired_at": None,
                     'logs': [],
                     'name': 'step2',
                     'number': 29,
@@ -361,7 +371,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
                     'stepid': 221,
                     'urls': []
                 }],
-                'url': 'http://localhost:8080/#builders/80/builds/3',
+                'url': 'http://localhost:8080/#/builders/80/builds/3',
                 'workerid': 13
             }],
             'buildset': {
@@ -409,7 +419,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
     def test_getResponsibleUsersForBuildWithBadOwner(self):
         self.setUpLogging()
         self.setupDb()
-        self.db.insertTestData([
+        self.db.insert_test_data([
             fakedb.BuildProperty(
                 buildid=20, name="owner", value=["him"]),
         ])
@@ -420,7 +430,7 @@ class TestDataUtils(TestReactorMixin, unittest.TestCase, logging.LoggingMixin):
     @defer.inlineCallbacks
     def test_getResponsibleUsersForBuildWithOwners(self):
         self.setupDb()
-        self.db.insertTestData([
+        self.db.insert_test_data([
             fakedb.BuildProperty(
                 buildid=20, name="owners", value=["him", "her"]),
         ])
@@ -450,4 +460,4 @@ class TestURLUtils(TestReactorMixin, unittest.TestCase):
 
     def test_UrlForBuild(self):
         self.assertEqual(utils.getURLForBuild(self.master, 1, 3),
-                         'http://localhost:8080/#builders/1/builds/3')
+                         'http://localhost:8080/#/builders/1/builds/3')
