@@ -17,8 +17,7 @@ import getpass
 import os
 import sys
 from io import StringIO
-
-import mock
+from unittest import mock
 
 from twisted.python import log
 from twisted.python import runtime
@@ -63,17 +62,17 @@ class TestUpgradeMasterOptions(OptionsMixin, unittest.TestCase):
 
     def test_defaults(self):
         opts = self.parse()
-        exp = dict(quiet=False, replace=False)
+        exp = {"quiet": False, "replace": False}
         self.assertOptions(opts, exp)
 
     def test_short(self):
         opts = self.parse('-q', '-r')
-        exp = dict(quiet=True, replace=True)
+        exp = {"quiet": True, "replace": True}
         self.assertOptions(opts, exp)
 
     def test_long(self):
         opts = self.parse('--quiet', '--replace')
-        exp = dict(quiet=True, replace=True)
+        exp = {"quiet": True, "replace": True}
         self.assertOptions(opts, exp)
 
 
@@ -88,10 +87,18 @@ class TestCreateMasterOptions(OptionsMixin, unittest.TestCase):
         return self.opts
 
     def defaults_and(self, **kwargs):
-        defaults = dict(force=False, relocatable=False, config='master.cfg',
-                        db='sqlite:///state.sqlite', basedir=os.getcwd(), quiet=False,
-                        **{'no-logrotate': False, 'log-size': 10000000,
-                           'log-count': 10})
+        defaults = {
+            "force": False,
+            "relocatable": False,
+            "config": 'master.cfg',
+            "db": 'sqlite:///state.sqlite',
+            "basedir": os.getcwd(),
+            "quiet": False, **{
+                'no-logrotate': False,
+                'log-size': 10000000,
+                'log-count': 10
+            }
+        }
         unk_keys = set(kwargs.keys()) - set(defaults.keys())
         assert not unk_keys, f"invalid keys {unk_keys}"
         opts = defaults.copy()
@@ -227,12 +234,12 @@ class BaseTestSimpleOptions(OptionsMixin):
 
     def test_defaults(self):
         opts = self.parse()
-        exp = dict(quiet=False)
+        exp = {"quiet": False}
         self.assertOptions(opts, exp)
 
     def test_quiet(self):
         opts = self.parse('--quiet')
-        exp = dict(quiet=True)
+        exp = {"quiet": True}
         self.assertOptions(opts, exp)
 
 
@@ -247,7 +254,7 @@ class TestResetartOptions(BaseTestSimpleOptions, unittest.TestCase):
 
     def test_nodaemon(self):
         opts = self.parse('--nodaemon')
-        exp = dict(nodaemon=True)
+        exp = {"nodaemon": True}
         self.assertOptions(opts, exp)
 
 
@@ -257,7 +264,7 @@ class TestStartOptions(BaseTestSimpleOptions, unittest.TestCase):
 
     def test_nodaemon(self):
         opts = self.parse('--nodaemon')
-        exp = dict(nodaemon=True)
+        exp = {"nodaemon": True}
         self.assertOptions(opts, exp)
 
 
@@ -277,12 +284,30 @@ class TestTryOptions(OptionsMixin, unittest.TestCase):
         return self.opts
 
     def defaults_and(self, **kwargs):
-        defaults = dict(connect=None, host=None, jobdir=None, username=None,
-                        master=None, passwd=None, who=None, comment=None, diff=None,
-                        patchlevel=0, baserev=None, vc=None, branch=None,
-                        repository=None, topfile=None, topdir=None, wait=False,
-                        dryrun=False, quiet=False, builders=[], properties={},
-                        buildbotbin='buildbot')
+        defaults = {
+            "connect": None,
+            "host": None,
+            "jobdir": None,
+            "username": None,
+            "master": None,
+            "passwd": None,
+            "who": None,
+            "comment": None,
+            "diff": None,
+            "patchlevel": 0,
+            "baserev": None,
+            "vc": None,
+            "branch": None,
+            "repository": None,
+            "topfile": None,
+            "topdir": None,
+            "wait": False,
+            "dryrun": False,
+            "quiet": False,
+            "builders": [],
+            "properties": {},
+            "buildbotbin": 'buildbot'
+        }
         # dashes make python syntax hard..
         defaults['get-builder-names'] = False
         if 'get_builder_names' in kwargs:
@@ -304,47 +329,47 @@ class TestTryOptions(OptionsMixin, unittest.TestCase):
 
     def test_properties(self):
         opts = self.parse('--properties=a=b')
-        exp = self.defaults_and(properties=dict(a='b'))
+        exp = self.defaults_and(properties={"a": 'b'})
         self.assertOptions(opts, exp)
 
     def test_properties_multiple_opts(self):
         opts = self.parse('--properties=X=1', '--properties=Y=2')
-        exp = self.defaults_and(properties=dict(X='1', Y='2'))
+        exp = self.defaults_and(properties={"X": '1', "Y": '2'})
         self.assertOptions(opts, exp)
 
     def test_properties_equals(self):
         opts = self.parse('--properties=X=2+2=4')
-        exp = self.defaults_and(properties=dict(X='2+2=4'))
+        exp = self.defaults_and(properties={"X": '2+2=4'})
         self.assertOptions(opts, exp)
 
     def test_properties_commas(self):
         opts = self.parse('--properties=a=b,c=d')
-        exp = self.defaults_and(properties=dict(a='b', c='d'))
+        exp = self.defaults_and(properties={"a": 'b', "c": 'd'})
         self.assertOptions(opts, exp)
 
     def test_property(self):
         opts = self.parse('--property=a=b')
-        exp = self.defaults_and(properties=dict(a='b'))
+        exp = self.defaults_and(properties={"a": 'b'})
         self.assertOptions(opts, exp)
 
     def test_property_multiple_opts(self):
         opts = self.parse('--property=X=1', '--property=Y=2')
-        exp = self.defaults_and(properties=dict(X='1', Y='2'))
+        exp = self.defaults_and(properties={"X": '1', "Y": '2'})
         self.assertOptions(opts, exp)
 
     def test_property_equals(self):
         opts = self.parse('--property=X=2+2=4')
-        exp = self.defaults_and(properties=dict(X='2+2=4'))
+        exp = self.defaults_and(properties={"X": '2+2=4'})
         self.assertOptions(opts, exp)
 
     def test_property_commas(self):
         opts = self.parse('--property=a=b,c=d')
-        exp = self.defaults_and(properties=dict(a='b,c=d'))
+        exp = self.defaults_and(properties={"a": 'b,c=d'})
         self.assertOptions(opts, exp)
 
     def test_property_and_properties(self):
         opts = self.parse('--property=X=1', '--properties=Y=2')
-        exp = self.defaults_and(properties=dict(X='1', Y='2'))
+        exp = self.defaults_and(properties={"X": '1', "Y": '2'})
         self.assertOptions(opts, exp)
 
     def test_properties_builders_multiple(self):
@@ -372,7 +397,7 @@ class TestTryOptions(OptionsMixin, unittest.TestCase):
                                 quiet=True, connect='pb', host='h', jobdir='j', username='u',
                                 master='m:1234', passwd='p', who='w', comment='comm', diff='d',
                                 patchlevel=7, baserev='br', vc='cvs', branch='br',
-                                repository='rep', builders=['bl'], properties=dict(a='b'),
+                                repository='rep', builders=['bl'], properties={"a": 'b'},
                                 topfile='Makefile', topdir='.',
                                 buildbotbin='.virtualenvs/buildbot/bin/buildbot')
         self.assertOptions(opts, exp)
@@ -384,37 +409,49 @@ class TestTryOptions(OptionsMixin, unittest.TestCase):
     def test_config_builders(self):
         self.options_file['try_builders'] = ['a', 'b']
         opts = self.parse()
-        self.assertOptions(opts, dict(builders=['a', 'b']))
+        self.assertOptions(opts, {"builders": ['a', 'b']})
 
     def test_config_builders_override(self):
         self.options_file['try_builders'] = ['a', 'b']
         opts = self.parse('-b', 'd')  # overrides a, b
-        self.assertOptions(opts, dict(builders=['d']))
+        self.assertOptions(opts, {"builders": ['d']})
 
     def test_config_old_names(self):
         self.options_file['try_masterstatus'] = 'ms'
         self.options_file['try_dir'] = 'td'
         self.options_file['try_password'] = 'pw'
         opts = self.parse()
-        self.assertOptions(opts, dict(master='ms', jobdir='td', passwd='pw'))
+        self.assertOptions(opts, {"master": 'ms', "jobdir": 'td', "passwd": 'pw'})
 
     def test_config_masterstatus(self):
         self.options_file['masterstatus'] = 'ms'
         opts = self.parse()
-        self.assertOptions(opts, dict(master='ms'))
+        self.assertOptions(opts, {"master": 'ms'})
 
     def test_config_masterstatus_override(self):
         self.options_file['masterstatus'] = 'ms'
         opts = self.parse('-m', 'mm')
-        self.assertOptions(opts, dict(master='mm'))
+        self.assertOptions(opts, {"master": 'mm'})
 
     def test_config_options(self):
-        self.options_file.update(dict(try_connect='pb', try_vc='cvs',
-                                      try_branch='br', try_repository='rep', try_topdir='.',
-                                      try_topfile='Makefile', try_host='h', try_username='u',
-                                      try_jobdir='j', try_password='p', try_master='m:8',
-                                      try_who='w', try_comment='comm', try_quiet='y', try_wait='y',
-                                      try_buildbotbin='.virtualenvs/buildbot/bin/buildbot'))
+        self.options_file.update({
+            "try_connect": 'pb',
+            "try_vc": 'cvs',
+            "try_branch": 'br',
+            "try_repository": 'rep',
+            "try_topdir": '.',
+            "try_topfile": 'Makefile',
+            "try_host": 'h',
+            "try_username": 'u',
+            "try_jobdir": 'j',
+            "try_password": 'p',
+            "try_master": 'm:8',
+            "try_who": 'w',
+            "try_comment": 'comm',
+            "try_quiet": 'y',
+            "try_wait": 'y',
+            "try_buildbotbin": '.virtualenvs/buildbot/bin/buildbot'
+        })
         opts = self.parse()
         exp = self.defaults_and(wait=True, quiet=True, connect='pb', host='h',
                                 jobdir='j', username='u', master='m:8', passwd='p', who='w',
@@ -460,11 +497,25 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
 
     def test_defaults(self):
         opts = self.parse('-m', 'm:1', '-W', 'me')
-        exp = dict(master='m:1', auth=('change', 'changepw'), who='me',
-                   vc=None, repository='', project='', branch=None, category=None,
-                   revision=None, revision_file=None, property=None,
-                   comments='', logfile=None, when=None, revlink='',
-                   encoding='utf8', files=())
+        exp = {
+            "master": 'm:1',
+            "auth": ('change', 'changepw'),
+            "who": 'me',
+            "vc": None,
+            "repository": '',
+            "project": '',
+            "branch": None,
+            "category": None,
+            "revision": None,
+            "revision_file": None,
+            "property": None,
+            "comments": '',
+            "logfile": None,
+            "when": None,
+            "revlink": '',
+            "encoding": 'utf8',
+            "files": ()
+        }
         self.assertOptions(opts, exp)
 
     def test_files(self):
@@ -474,11 +525,11 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
     def test_properties(self):
         opts = self.parse('--property', 'x:y', '--property', 'a:b',
                           *self.master_and_who)
-        self.assertEqual(opts['properties'], dict(x="y", a="b"))
+        self.assertEqual(opts['properties'], {"x": 'y', "a": 'b'})
 
     def test_properties_with_colon(self):
         opts = self.parse('--property', 'x:http://foo', *self.master_and_who)
-        self.assertEqual(opts['properties'], dict(x='http://foo'))
+        self.assertEqual(opts['properties'], {"x": 'http://foo'})
 
     def test_config_file(self):
         self.options_file['master'] = 'MMM:123'
@@ -487,17 +538,29 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
         self.options_file['category'] = 'CCC'
         self.options_file['vc'] = 'svn'
         opts = self.parse()
-        exp = dict(master='MMM:123', who='WWW',
-                   branch='BBB', category='CCC', vc='svn')
+        exp = {"master": 'MMM:123', "who": 'WWW', "branch": 'BBB', "category": 'CCC', "vc": 'svn'}
         self.assertOptions(opts, exp)
 
     def test_short_args(self):
         opts = self.parse(*('-m m:1 -a a:b -W W -R r -P p -b b -s git ' +
                             '-C c -r r -p pn:pv -c c -F f -w 123 -l l -e e').split())
-        exp = dict(master='m:1', auth=('a', 'b'), who='W', repository='r',
-                   project='p', branch='b', category='c', revision='r', vc='git',
-                   properties=dict(pn='pv'), comments='c', logfile='f',
-                   when=123.0, revlink='l', encoding='e')
+        exp = {
+            "master": 'm:1',
+            "auth": ('a', 'b'),
+            "who": 'W',
+            "repository": 'r',
+            "project": 'p',
+            "branch": 'b',
+            "category": 'c',
+            "revision": 'r',
+            "vc": 'git',
+            "properties": {"pn": 'pv'},
+            "comments": 'c',
+            "logfile": 'f',
+            "when": 123.0,
+            "revlink": 'l',
+            "encoding": 'e'
+        }
         self.assertOptions(opts, exp)
 
     def test_long_args(self):
@@ -505,10 +568,23 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
                             '--project p --branch b --category c --revision r --vc git ' +
                             '--property pn:pv --comments c --logfile f ' +
                             '--when 123 --revlink l --encoding e').split())
-        exp = dict(master='m:1', auth=('a', 'b'), who='w', repository='r',
-                   project='p', branch='b', category='c', revision='r', vc='git',
-                   properties=dict(pn='pv'), comments='c', logfile='f',
-                   when=123.0, revlink='l', encoding='e')
+        exp = {
+            "master": 'm:1',
+            "auth": ('a', 'b'),
+            "who": 'w',
+            "repository": 'r',
+            "project": 'p',
+            "branch": 'b',
+            "category": 'c',
+            "revision": 'r',
+            "vc": 'git',
+            "properties": {"pn": 'pv'},
+            "comments": 'c',
+            "logfile": 'f',
+            "when": 123.0,
+            "revlink": 'l',
+            "encoding": 'e'
+        }
         self.assertOptions(opts, exp)
 
     def test_revision_file(self):
@@ -516,7 +592,7 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
             f.write('my-rev')
         self.addCleanup(lambda: os.unlink('revfile'))
         opts = self.parse('--revision_file', 'revfile', *self.master_and_who)
-        self.assertOptions(opts, dict(revision='my-rev'))
+        self.assertOptions(opts, {"revision": 'my-rev'})
 
     def test_invalid_when(self):
         with self.assertRaises(usage.UsageError):
@@ -525,25 +601,25 @@ class TestSendChangeOptions(OptionsMixin, unittest.TestCase):
     def test_comments_overrides_logfile(self):
         opts = self.parse('--logfile', 'logs', '--comments', 'foo',
                           *self.master_and_who)
-        self.assertOptions(opts, dict(comments='foo'))
+        self.assertOptions(opts, {"comments": 'foo'})
 
     def test_logfile(self):
         with open('comments', 'wt', encoding='utf-8') as f:
             f.write('hi')
         self.addCleanup(lambda: os.unlink('comments'))
         opts = self.parse('--logfile', 'comments', *self.master_and_who)
-        self.assertOptions(opts, dict(comments='hi'))
+        self.assertOptions(opts, {"comments": 'hi'})
 
     def test_logfile_stdin(self):
         stdin = mock.Mock()
         stdin.read = lambda: 'hi'
         self.patch(sys, 'stdin', stdin)
         opts = self.parse('--logfile', '-', *self.master_and_who)
-        self.assertOptions(opts, dict(comments='hi'))
+        self.assertOptions(opts, {"comments": 'hi'})
 
     def test_auth_getpass(self):
         opts = self.parse('--auth=dustin', *self.master_and_who)
-        self.assertOptions(opts, dict(auth=('dustin', 'typed-password')))
+        self.assertOptions(opts, {"auth": ('dustin', 'typed-password')})
 
     def test_invalid_vcs(self):
         with self.assertRaises(usage.UsageError):
@@ -574,7 +650,7 @@ class TestTryServerOptions(OptionsMixin, unittest.TestCase):
 
     def test_with_jobdir(self):
         opts = self.parse('--jobdir', 'xyz')
-        exp = dict(jobdir='xyz')
+        exp = {"jobdir": 'xyz'}
         self.assertOptions(opts, exp)
 
 
@@ -594,17 +670,17 @@ class TestCheckConfigOptions(OptionsMixin, unittest.TestCase):
 
     def test_defaults(self):
         opts = self.parse()
-        exp = dict(quiet=False)
+        exp = {"quiet": False}
         self.assertOptions(opts, exp)
 
     def test_configfile(self):
         opts = self.parse('foo.cfg')
-        exp = dict(quiet=False, configFile='foo.cfg')
+        exp = {"quiet": False, "configFile": 'foo.cfg'}
         self.assertOptions(opts, exp)
 
     def test_quiet(self):
         opts = self.parse('-q')
-        exp = dict(quiet=True)
+        exp = {"quiet": True}
         self.assertOptions(opts, exp)
 
 
@@ -633,7 +709,7 @@ class TestUserOptions(OptionsMixin, unittest.TestCase):
     def test_master(self):
         opts = self.parse("--master", "abcd:1234",
                           '--op=get', '--ids=x', '--username=u', '--passwd=p')
-        self.assertOptions(opts, dict(master="abcd:1234"))
+        self.assertOptions(opts, {"master": 'abcd:1234'})
 
     def test_ids(self):
         opts = self.parse("--ids", "id1,id2,id3",
@@ -644,26 +720,26 @@ class TestUserOptions(OptionsMixin, unittest.TestCase):
         opts = self.parse("--info", "git=Tyler Durden <tyler@mayhem.net>",
                           '--op', 'add', *self.extra_args)
         self.assertEqual(opts['info'],
-                         [dict(git='Tyler Durden <tyler@mayhem.net>')])
+                         [{"git": 'Tyler Durden <tyler@mayhem.net>'}])
 
     def test_info_only_id(self):
         opts = self.parse("--info", "tdurden",
                           '--op', 'update', *self.extra_args)
-        self.assertEqual(opts['info'], [dict(identifier='tdurden')])
+        self.assertEqual(opts['info'], [{"identifier": 'tdurden'}])
 
     def test_info_with_id(self):
         opts = self.parse("--info", "tdurden:svn=marla",
                           '--op', 'update', *self.extra_args)
         self.assertEqual(
-            opts['info'], [dict(identifier='tdurden', svn='marla')])
+            opts['info'], [{"identifier": 'tdurden', "svn": 'marla'}])
 
     def test_info_multiple(self):
         opts = self.parse("--info", "git=Tyler Durden <tyler@mayhem.net>",
                           "--info", "git=Narrator <narrator@mayhem.net>",
                           '--op', 'add', *self.extra_args)
         self.assertEqual(opts['info'],
-                         [dict(git='Tyler Durden <tyler@mayhem.net>'),
-                          dict(git='Narrator <narrator@mayhem.net>')])
+                         [{"git": 'Tyler Durden <tyler@mayhem.net>'},
+                          {"git": 'Narrator <narrator@mayhem.net>'}])
 
     def test_config_user_params(self):
         self.options_file['user_master'] = 'mm:99'
@@ -671,20 +747,20 @@ class TestUserOptions(OptionsMixin, unittest.TestCase):
         self.options_file['user_passwd'] = 'pw'
         opts = self.parse('--op', 'get', '--ids', 'x')
         self.assertOptions(
-            opts, dict(master='mm:99', username='un', passwd='pw'))
+            opts, {"master": 'mm:99', "username": 'un', "passwd": 'pw'})
 
     def test_config_master(self):
         self.options_file['master'] = 'mm:99'
         opts = self.parse('--op', 'get', '--ids', 'x',
                           '--username=u', '--passwd=p')
-        self.assertOptions(opts, dict(master='mm:99'))
+        self.assertOptions(opts, {"master": 'mm:99'})
 
     def test_config_master_override(self):
         self.options_file['master'] = 'not seen'
         self.options_file['user_master'] = 'mm:99'
         opts = self.parse('--op', 'get', '--ids', 'x',
                           '--username=u', '--passwd=p')
-        self.assertOptions(opts, dict(master='mm:99'))
+        self.assertOptions(opts, {"master": 'mm:99'})
 
     def test_invalid_info(self):
         with self.assertRaises(usage.UsageError):
