@@ -16,8 +16,7 @@
 import os
 import sys
 from io import StringIO
-
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.trial import unittest
@@ -35,7 +34,7 @@ from buildbot.test.util import www
 
 
 def mkconfig(**kwargs):
-    config = dict(quiet=False, replace=False, basedir='test')
+    config = {"quiet": False, "replace": False, "basedir": 'test'}
     config.update(kwargs)
     return config
 
@@ -78,7 +77,7 @@ class TestUpgradeMaster(dirs.DirsMixin, misc.StdoutAssertionsMixin,
     @defer.inlineCallbacks
     def test_upgradeMaster_success(self):
         self.patchFunctions()
-        rv = yield upgrade_master.upgradeMaster(mkconfig(), _noMonkey=True)
+        rv = yield upgrade_master.upgradeMaster(mkconfig())
 
         self.assertEqual(rv, 0)
         self.assertInStdout('upgrade complete')
@@ -86,7 +85,7 @@ class TestUpgradeMaster(dirs.DirsMixin, misc.StdoutAssertionsMixin,
     @defer.inlineCallbacks
     def test_upgradeMaster_quiet(self):
         self.patchFunctions()
-        rv = yield upgrade_master.upgradeMaster(mkconfig(quiet=True), _noMonkey=True)
+        rv = yield upgrade_master.upgradeMaster(mkconfig(quiet=True))
 
         self.assertEqual(rv, 0)
         self.assertWasQuiet()
@@ -94,14 +93,14 @@ class TestUpgradeMaster(dirs.DirsMixin, misc.StdoutAssertionsMixin,
     @defer.inlineCallbacks
     def test_upgradeMaster_bad_basedir(self):
         self.patchFunctions(basedirOk=False)
-        rv = yield upgrade_master.upgradeMaster(mkconfig(), _noMonkey=True)
+        rv = yield upgrade_master.upgradeMaster(mkconfig())
 
         self.assertEqual(rv, 1)
 
     @defer.inlineCallbacks
     def test_upgradeMaster_bad_config(self):
         self.patchFunctions(configOk=False)
-        rv = yield upgrade_master.upgradeMaster(mkconfig(), _noMonkey=True)
+        rv = yield upgrade_master.upgradeMaster(mkconfig())
 
         self.assertEqual(rv, 1)
 
