@@ -69,7 +69,7 @@ class Tests(unittest.TestCase):
         }
 
     def test_basic(self):
-        self.patch(config, "_in_unit_tests", False)
+        self.patch(config.master, "get_is_in_unit_tests", lambda: False)
         with assertProducesWarning(
                 ConfigWarning,
                 message_pattern=r"`buildbotNetUsageData` is not configured and defaults to basic."):
@@ -81,7 +81,7 @@ class Tests(unittest.TestCase):
         self.assertEqual(data['plugins']['buildbot/worker/base/Worker'], 3)
         self.assertEqual(sorted(data['plugins'].keys()), sorted(
             ['buildbot/schedulers/forcesched/ForceScheduler', 'buildbot/worker/base/Worker',
-             'buildbot/steps/shell_oldstyle/ShellCommand', 'buildbot/config/BuilderConfig']))
+             'buildbot/steps/shell/ShellCommand', 'buildbot/config/builder/BuilderConfig']))
 
     def test_full(self):
         c = self.getBaseConfig()
@@ -96,7 +96,7 @@ class Tests(unittest.TestCase):
         c = self.getBaseConfig()
 
         def myCompute(data):
-            return dict(db=data['db'])
+            return {"db": data['db']}
         c['buildbotNetUsageData'] = myCompute
         master = self.getMaster(c)
         data = computeUsageData(master)
@@ -151,5 +151,5 @@ class Tests(unittest.TestCase):
         self.assertEqual(len(distro), 2)
         self.assertNotIn("unknown", distro[0])
         # Rolling distributions like Arch Linux (arch) does not have VERSION_ID
-        if distro[0] not in ["arch", "gentoo"]:
+        if distro[0] not in ["arch", "gentoo", "antergos"]:
             self.assertNotIn("unknown", distro[1])
