@@ -13,7 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.trial import unittest
@@ -31,7 +31,7 @@ class Tests(interfaces.InterfaceTests):
         raise NotImplementedError
 
     def test_empty_produce(self):
-        self.mq.produce(('a', 'b', 'c'), dict(x=1))
+        self.mq.produce(('a', 'b', 'c'), {"x": 1})
         # ..nothing happens
 
     def test_signature_produce(self):
@@ -77,10 +77,10 @@ class RealTests(tuplematching.TupleMatchingMixin, Tests):
     def test_stopConsuming(self):
         cb = mock.Mock()
         qref = yield self.mq.startConsuming(cb, ('abc',))
-        self.mq.produce(('abc',), dict(x=1))
+        self.mq.produce(('abc',), {"x": 1})
         qref.stopConsuming()
-        self.mq.produce(('abc',), dict(x=1))
-        cb.assert_called_once_with(('abc',), dict(x=1))
+        self.mq.produce(('abc',), {"x": 1})
+        cb.assert_called_once_with(('abc',), {"x": 1})
 
     @defer.inlineCallbacks
     def test_stopConsuming_twice(self):
@@ -126,10 +126,10 @@ class RealTests(tuplematching.TupleMatchingMixin, Tests):
     def test_waitUntilEvent_check_false(self):
         d = self.mq.waitUntilEvent(('abc',), lambda: False)
         self.assertEqual(d.called, False)
-        self.mq.produce(('abc',), dict(x=1))
+        self.mq.produce(('abc',), {"x": 1})
         self.assertEqual(d.called, True)
         res = yield d
-        self.assertEqual(res, (('abc',), dict(x=1)))
+        self.assertEqual(res, (('abc',), {"x": 1}))
     timeout = 3  # those tests should not run long
 
 
