@@ -16,8 +16,7 @@
 import datetime
 import json
 import os
-
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.internet import reactor
@@ -67,19 +66,22 @@ class HTTPClientServiceTestTxRequest(HTTPClientServiceTestBase):
         self._http = yield httpclientservice.HTTPClientService.getService(
             self.parent, 'http://foo', headers=self.base_headers)
 
+    @defer.inlineCallbacks
     def test_get(self):
-        self._http.get('/bar')
+        yield self._http.get('/bar')
         self._http._session.request.assert_called_once_with('get', 'http://foo/bar', headers={},
                                                             background_callback=mock.ANY)
 
+    @defer.inlineCallbacks
     def test_get_full_url(self):
-        self._http.get('http://other/bar')
+        yield self._http.get('http://other/bar')
         self._http._session.request.assert_called_once_with('get', 'http://other/bar', headers={},
                                                             background_callback=mock.ANY)
 
+    @defer.inlineCallbacks
     def test_put(self):
-        self._http.put('/bar', json={'foo': 'bar'})
-        jsonStr = json.dumps(dict(foo='bar'))
+        yield self._http.put('/bar', json={'foo': 'bar'})
+        jsonStr = json.dumps({"foo": 'bar'})
         jsonBytes = unicode2bytes(jsonStr)
         headers = {'Content-Type': 'application/json'}
         self._http._session.request.assert_called_once_with('put', 'http://foo/bar',
@@ -87,9 +89,10 @@ class HTTPClientServiceTestTxRequest(HTTPClientServiceTestBase):
                                                             data=jsonBytes,
                                                             headers=headers)
 
+    @defer.inlineCallbacks
     def test_post(self):
-        self._http.post('/bar', json={'foo': 'bar'})
-        jsonStr = json.dumps(dict(foo='bar'))
+        yield self._http.post('/bar', json={'foo': 'bar'})
+        jsonStr = json.dumps({"foo": 'bar'})
         jsonBytes = unicode2bytes(jsonStr)
         headers = {'Content-Type': 'application/json'}
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
@@ -97,16 +100,18 @@ class HTTPClientServiceTestTxRequest(HTTPClientServiceTestBase):
                                                             data=jsonBytes,
                                                             headers=headers)
 
+    @defer.inlineCallbacks
     def test_delete(self):
-        self._http.delete('/bar')
+        yield self._http.delete('/bar')
         self._http._session.request.assert_called_once_with('delete', 'http://foo/bar',
                                                             background_callback=mock.ANY,
                                                             headers={})
 
+    @defer.inlineCallbacks
     def test_post_headers(self):
         self.base_headers.update({'X-TOKEN': 'XXXYYY'})
-        self._http.post('/bar', json={'foo': 'bar'})
-        jsonStr = json.dumps(dict(foo='bar'))
+        yield self._http.post('/bar', json={'foo': 'bar'})
+        jsonStr = json.dumps({"foo": 'bar'})
         jsonBytes = unicode2bytes(jsonStr)
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
                                                             background_callback=mock.ANY,
@@ -119,8 +124,8 @@ class HTTPClientServiceTestTxRequest(HTTPClientServiceTestBase):
     def test_post_auth(self):
         self._http = yield httpclientservice.HTTPClientService.getService(self.parent, 'http://foo',
                                                                           auth=('user', 'pa$$'))
-        self._http.post('/bar', json={'foo': 'bar'})
-        jsonStr = json.dumps(dict(foo='bar'))
+        yield self._http.post('/bar', json={'foo': 'bar'})
+        jsonStr = json.dumps({"foo": 'bar'})
         jsonBytes = unicode2bytes(jsonStr)
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
                                                             background_callback=mock.ANY,
@@ -142,18 +147,20 @@ class HTTPClientServiceTestTxRequestNoEncoding(HTTPClientServiceTestBase):
                                                            headers=self.base_headers,
                                                            skipEncoding=True))
 
+    @defer.inlineCallbacks
     def test_post_raw(self):
-        self._http.post('/bar', json={'foo': 'bar'})
-        jsonStr = json.dumps(dict(foo='bar'))
+        yield self._http.post('/bar', json={'foo': 'bar'})
+        jsonStr = json.dumps({"foo": 'bar'})
         headers = {'Content-Type': 'application/json'}
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
                                                             background_callback=mock.ANY,
                                                             data=jsonStr,
                                                             headers=headers)
 
+    @defer.inlineCallbacks
     def test_post_rawlist(self):
-        self._http.post('/bar', json=[{'foo': 'bar'}])
-        jsonStr = json.dumps([dict(foo='bar')])
+        yield self._http.post('/bar', json=[{'foo': 'bar'}])
+        jsonStr = json.dumps([{"foo": 'bar'}])
         headers = {'Content-Type': 'application/json'}
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
                                                             background_callback=mock.ANY,
@@ -170,37 +177,42 @@ class HTTPClientServiceTestTReq(HTTPClientServiceTestBase):
         self._http = yield httpclientservice.HTTPClientService.getService(
             self.parent, 'http://foo', headers=self.base_headers)
 
+    @defer.inlineCallbacks
     def test_get(self):
-        self._http.get('/bar')
+        yield self._http.get('/bar')
         httpclientservice.treq.get.assert_called_once_with('http://foo/bar',
                                                            agent=mock.ANY,
                                                            headers={})
 
+    @defer.inlineCallbacks
     def test_put(self):
-        self._http.put('/bar', json={'foo': 'bar'})
+        yield self._http.put('/bar', json={'foo': 'bar'})
         headers = {'Content-Type': ['application/json']}
         httpclientservice.treq.put.assert_called_once_with('http://foo/bar',
                                                            agent=mock.ANY,
                                                            data=b'{"foo": "bar"}',
                                                            headers=headers)
 
+    @defer.inlineCallbacks
     def test_post(self):
-        self._http.post('/bar', json={'foo': 'bar'})
+        yield self._http.post('/bar', json={'foo': 'bar'})
         headers = {'Content-Type': ['application/json']}
         httpclientservice.treq.post.assert_called_once_with('http://foo/bar',
                                                             agent=mock.ANY,
                                                             data=b'{"foo": "bar"}',
                                                             headers=headers)
 
+    @defer.inlineCallbacks
     def test_delete(self):
-        self._http.delete('/bar')
+        yield self._http.delete('/bar')
         httpclientservice.treq.delete.assert_called_once_with('http://foo/bar',
                                                               agent=mock.ANY,
                                                               headers={})
 
+    @defer.inlineCallbacks
     def test_post_headers(self):
         self.base_headers.update({'X-TOKEN': 'XXXYYY'})
-        self._http.post('/bar', json={'foo': 'bar'})
+        yield self._http.post('/bar', json={'foo': 'bar'})
         headers = {
             'Content-Type': ['application/json'],
             'X-TOKEN': ['XXXYYY']
@@ -214,7 +226,7 @@ class HTTPClientServiceTestTReq(HTTPClientServiceTestBase):
     def test_post_auth(self):
         self._http = yield httpclientservice.HTTPClientService.getService(self.parent, 'http://foo',
                                                                           auth=('user', 'pa$$'))
-        self._http.post('/bar', json={'foo': 'bar'})
+        yield self._http.post('/bar', json={'foo': 'bar'})
         headers = {
             'Content-Type': ['application/json'],
         }
@@ -230,12 +242,11 @@ class HTTPClientServiceTestTReq(HTTPClientServiceTestBase):
         auth = HTTPDigestAuth('user', 'pa$$')
         self._http = yield httpclientservice.HTTPClientService.getService(self.parent, 'http://foo',
                                                                           auth=auth)
-        self._http.post('/bar', data={'foo': 'bar'})
+        yield self._http.post('/bar', data={'foo': 'bar'})
         # if digest auth, we don't use treq! we use txrequests
         self._http._session.request.assert_called_once_with('post', 'http://foo/bar',
                                                             background_callback=mock.ANY,
-                                                            data=dict(
-                                                                foo='bar'),
+                                                            data={"foo": 'bar'},
                                                             auth=auth,
                                                             headers={
                                                             })
@@ -252,18 +263,20 @@ class HTTPClientServiceTestTReqNoEncoding(HTTPClientServiceTestBase):
                                                            headers=self.base_headers,
                                                            skipEncoding=True))
 
+    @defer.inlineCallbacks
     def test_post_raw(self):
-        self._http.post('/bar', json={'foo': 'bar'})
-        json_str = json.dumps(dict(foo='bar'))
+        yield self._http.post('/bar', json={'foo': 'bar'})
+        json_str = json.dumps({"foo": 'bar'})
         headers = {'Content-Type': ['application/json']}
         httpclientservice.treq.post.assert_called_once_with('http://foo/bar',
                                                             agent=mock.ANY,
                                                             data=json_str,
                                                             headers=headers)
 
+    @defer.inlineCallbacks
     def test_post_rawlist(self):
-        self._http.post('/bar', json=[{'foo': 'bar'}])
-        json_str = json.dumps([dict(foo='bar')])
+        yield self._http.post('/bar', json=[{'foo': 'bar'}])
+        json_str = json.dumps([{"foo": 'bar'}])
         headers = {'Content-Type': ['application/json']}
         httpclientservice.treq.post.assert_called_once_with('http://foo/bar',
                                                             agent=mock.ANY,
@@ -320,6 +333,10 @@ class HTTPClientServiceTestTxRequestE2E(unittest.TestCase):
 
     @defer.inlineCallbacks
     def setUp(self):
+        # On slower machines with high CPU oversubscription this test may take longer to run than
+        # the default timeout.
+        self.timeout = 10
+
         if httpclientservice.txrequests is None or httpclientservice.treq is None:
             raise unittest.SkipTest('this test requires txrequests and treq')
         site = server.Site(MyResource())
@@ -344,32 +361,32 @@ class HTTPClientServiceTestTxRequestE2E(unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_content_with_params(self):
-        self.expect('get', '/', params=dict(a='b'), content_json=dict(a=['b']))
-        res = yield self._http.get('/', params=dict(a='b'))
+        self.expect('get', '/', params={"a": 'b'}, content_json={"a": ['b']})
+        res = yield self._http.get('/', params={"a": 'b'})
         content = yield res.content()
         self.assertEqual(content, b'{"a": ["b"]}')
 
     @defer.inlineCallbacks
     def test_post_content_with_params(self):
-        self.expect('post', '/', params=dict(a='b'),
-                    content_json=dict(a=['b']))
-        res = yield self._http.post('/', params=dict(a='b'))
+        self.expect('post', '/', params={"a": 'b'},
+                    content_json={"a": ['b']})
+        res = yield self._http.post('/', params={"a": 'b'})
         content = yield res.content()
         self.assertEqual(content, b'{"a": ["b"]}')
 
     @defer.inlineCallbacks
     def test_put_content_with_data(self):
-        self.expect('post', '/', data=dict(a='b'), content_json=dict(a=['b']))
-        res = yield self._http.post('/', data=dict(a='b'))
+        self.expect('post', '/', data={"a": 'b'}, content_json={"a": ['b']})
+        res = yield self._http.post('/', data={"a": 'b'})
         content = yield res.content()
         self.assertEqual(content, b'{"a": ["b"]}')
 
     @defer.inlineCallbacks
     def test_put_content_with_json(self):
-        exp_content_json = dict(json_received=dict(a='b'))
-        self.expect('post', '/', json=dict(a='b'),
+        exp_content_json = {"json_received": {"a": 'b'}}
+        self.expect('post', '/', json={"a": 'b'},
                     content_json=exp_content_json)
-        res = yield self._http.post('/', json=dict(a='b'))
+        res = yield self._http.post('/', json={"a": 'b'})
         content = yield res.content()
         content = bytes2unicode(content)
         content = json.loads(content)
@@ -377,11 +394,11 @@ class HTTPClientServiceTestTxRequestE2E(unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_put_content_with_json_datetime(self):
-        exp_content_json = dict(json_received=dict(a='b', ts=12))
-        dt = datetime.datetime.utcfromtimestamp(12)
-        self.expect('post', '/', json=dict(a='b', ts=dt),
+        exp_content_json = {"json_received": {"a": 'b', "ts": 12}}
+        dt = datetime.datetime.fromtimestamp(12, datetime.timezone.utc)
+        self.expect('post', '/', json={"a": 'b', "ts": dt},
                     content_json=exp_content_json)
-        res = yield self._http.post('/', json=dict(a='b', ts=dt))
+        res = yield self._http.post('/', json={"a": 'b', "ts": dt})
         content = yield res.content()
         content = bytes2unicode(content)
         content = json.loads(content)
@@ -402,25 +419,25 @@ class HTTPClientServiceTestTxRequestE2E(unittest.TestCase):
     @defer.inlineCallbacks
     def test_lots(self):
         for _ in range(self.NUM_PARALLEL):
-            self.expect('get', '/', params=dict(a='b'),
-                        content_json=dict(a=['b']))
+            self.expect('get', '/', params={"a": 'b'},
+                        content_json={"a": ['b']})
         # use for benchmarking (txrequests: 3ms per request treq: 1ms per
         # request)
         for _ in range(self.NUM_PARALLEL):
-            res = yield self._http.get('/', params=dict(a='b'))
+            res = yield self._http.get('/', params={"a": 'b'})
             content = yield res.content()
             self.assertEqual(content, b'{"a": ["b"]}')
 
     @defer.inlineCallbacks
     def test_lots_parallel(self):
         for _ in range(self.NUM_PARALLEL):
-            self.expect('get', '/', params=dict(a='b'),
-                        content_json=dict(a=['b']))
+            self.expect('get', '/', params={"a": 'b'},
+                        content_json={"a": ['b']})
 
         # use for benchmarking (txrequests: 3ms per request treq: 11ms per
         # request (!?))
         def oneReq():
-            d = self._http.get('/', params=dict(a='b'))
+            d = self._http.get('/', params={"a": 'b'})
 
             @d.addCallback
             def content(res):
