@@ -30,8 +30,8 @@ class Tests(unittest.TestCase):
         except UnicodeEncodeError as e:
             # Default encoding of Windows console is 'cp1252'
             # which cannot encode the snowman.
-            raise(unittest.SkipTest("Cannot encode weird unicode "
-                f"on this platform with {os_encoding}")) from e
+            raise unittest.SkipTest("Cannot encode weird unicode "
+                f"on this platform with {os_encoding}") from e
 
         good = [
             "linux", "Linux", "abc123", "a" * 50, '\N{SNOWMAN}'
