@@ -15,11 +15,10 @@
 
 import calendar
 import datetime
+from unittest import mock
 
 import jwt
 
-import mock
-
 from twisted.cred import strcred
 from twisted.cred.checkers import InMemoryUsernamePasswordDatabaseDontUse
 from twisted.internet import defer
@@ -69,7 +68,7 @@ class Test(TestReactorMixin, www.WwwTestMixin, unittest.TestCase):
         yield self.svc.setServiceParent(self.master)
 
     def makeConfig(self, **kwargs):
-        w = dict(port=None, auth=auth.NoAuth(), logfileName='l')
+        w = {"port": None, "auth": auth.NoAuth(), "logfileName": 'l'}
         w.update(kwargs)
         new_config = mock.Mock()
         new_config.www = w
@@ -247,7 +246,7 @@ class TestBuildbotSite(unittest.SynchronousTestCase):
 
     def test_getSession_from_expired_jwt(self):
         # expired one week ago
-        exp = datetime.datetime.utcnow() - datetime.timedelta(weeks=1)
+        exp = datetime.datetime.now(datetime.timezone.utc) - datetime.timedelta(weeks=1)
         exp = calendar.timegm(datetime.datetime.timetuple(exp))
         payload = {'user_info': {'some': 'payload'}, 'exp': exp}
         uid = jwt.encode(payload, self.SECRET, algorithm=service.SESSION_SECRET_ALGORITHM)
