@@ -27,7 +27,6 @@ from buildbot.db import enginestrategy
 from buildbot.db import model
 from buildbot.db import pool
 from buildbot.db.connector import DBConnector
-from buildbot.util.sautils import sa_version
 from buildbot.util.sautils import withoutSqliteForeignKeys
 
 
@@ -36,12 +35,47 @@ def skip_for_dialect(dialect):
     def dec(fn):
         def wrap(self, *args, **kwargs):
             if self.db_engine.dialect.name == dialect:
-                raise unittest.SkipTest("Not supported on dialect '{}'".format(dialect))
+                raise unittest.SkipTest(f"Not supported on dialect '{dialect}'")
             return fn(self, *args, **kwargs)
         return wrap
     return dec
 
 
+def get_trial_parallel_from_cwd(cwd):
+    cwd = cwd.rstrip("/")
+    last = os.path.basename(cwd)
+    prev = os.path.basename(os.path.dirname(cwd))
+    if last == "_trial_temp":
+        return False
+    if prev == "_trial_temp":
+        try:
+            return int(last)
+        except ValueError:
+            return None
+    return None
+
+
+def resolve_test_index_in_db_url(db_url):
+    test_id = get_trial_parallel_from_cwd(os.getcwd())
+
+    if "{TEST_ID}" in db_url:
+        return db_url.replace("{TEST_ID}", str(test_id or 0))
+
+    if db_url == 'sqlite://':
+        return db_url
+
+    if test_id is not None and test_id is not False:
+        if db_url.startswith('sqlite:///'):
+            # Relative DB URLs in the test directory are fine.
+            path = db_url[len('sqlite:///'):]
+            if not os.path.relpath(path).startswith(".."):
+                return db_url
+
+        raise RuntimeError("Database tests cannnot run in parallel")
+
+    return db_url
+
+
 class RealDatabaseMixin:
 
     """
@@ -125,24 +159,19 @@ class RealDatabaseMixin:
             # non-existent table in SQLite.
             meta.reflect()
 
-            # Table.foreign_key_constraints introduced in SQLAlchemy 1.0.
-            if sa_version()[:2] >= (1, 0):
-                # Restore `use_alter` settings to break known reference cycles.
-                # Main goal of this part is to remove SQLAlchemy warning
-                # about reference cycle.
-                # Looks like it's OK to do it only with SQLAlchemy >= 1.0.0,
-                # since it's not issued in SQLAlchemy == 0.8.0
+            # Restore `use_alter` settings to break known reference cycles.
+            # Main goal of this part is to remove SQLAlchemy warning
+            # about reference cycle.
 
-                # List of reference links (table_name, ref_table_name) that
-                # should be broken by adding use_alter=True.
-                table_referenced_table_links = [
-                    ('buildsets', 'builds'), ('builds', 'buildrequests')]
-                for table_name, ref_table_name in table_referenced_table_links:
-                    if table_name in meta.tables:
-                        table = meta.tables[table_name]
-                        for fkc in table.foreign_key_constraints:
-                            if fkc.referred_table.name == ref_table_name:
-                                fkc.use_alter = True
+            # List of reference links (table_name, ref_table_name) that
+            # should be broken by adding use_alter=True.
+            table_referenced_table_links = [('buildsets', 'builds'), ('builds', 'buildrequests')]
+            for table_name, ref_table_name in table_referenced_table_links:
+                if table_name in meta.tables:
+                    table = meta.tables[table_name]
+                    for fkc in table.foreign_key_constraints:
+                        if fkc.referred_table.name == ref_table_name:
+                            fkc.use_alter = True
 
             # Drop all reflected tables and indices. May fail, e.g. if
             # SQLAlchemy wouldn't be able to break circular references.
@@ -197,6 +226,8 @@ class RealDatabaseMixin:
         if not sqlite_memory and self.db_url == default_sqlite:
             self.db_url = "sqlite:///tmp.sqlite"
 
+        self.db_url = resolve_test_index_in_db_url(self.db_url)
+
         if not os.path.exists(basedir):
             os.makedirs(basedir)
 
@@ -209,7 +240,7 @@ class RealDatabaseMixin:
 
         self.db_pool = pool.DBThreadPool(self.db_engine, reactor=reactor)
 
-        log.msg("cleaning database {}".format(self.db_url))
+        log.msg(f"cleaning database {self.db_url}")
         yield self.db_pool.do(self.__thd_clean_database)
         yield self.db_pool.do(self.__thd_create_tables, table_names)
         return None
@@ -221,7 +252,7 @@ class RealDatabaseMixin:
             yield self.db_pool.shutdown()
 
     @defer.inlineCallbacks
-    def insertTestData(self, rows):
+    def insert_test_data(self, rows):
         """Insert test data into the database for use during the test.
 
         @param rows: be a sequence of L{fakedb.Row} instances.  These will be
@@ -242,7 +273,7 @@ class RealDatabaseMixin:
                     try:
                         tbl.insert(bind=conn).execute(row.values)
                     except Exception:
-                        log.msg("while inserting {} - {}".format(row, row.values))
+                        log.msg(f"while inserting {row} - {row.values}")
                         raise
         yield self.db_pool.do(thd)
 
