@@ -14,17 +14,19 @@
 # Copyright Buildbot Team Members
 
 
+from twisted import trial
 from twisted.internet import defer
 
 from buildbot.data import base
 from buildbot.data import resultspec
 from buildbot.test.fake import fakemaster
+from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import interfaces
 from buildbot.test.util import validation
 from buildbot.util import pathmatch
 
 
-class EndpointMixin(interfaces.InterfaceTests):
+class EndpointMixin(TestReactorMixin, interfaces.InterfaceTests):
     # test mixin for testing Endpoint subclasses
 
     # class being tested
@@ -35,8 +37,9 @@ class EndpointMixin(interfaces.InterfaceTests):
     resourceTypeClass = None
 
     def setUpEndpoint(self):
-        self.master = fakemaster.make_master(wantMq=True, wantDb=True,
-                                             wantData=True, testcase=self)
+        self.setup_test_reactor()
+        self.master = fakemaster.make_master(self, wantMq=True, wantDb=True,
+                                             wantData=True)
         self.db = self.master.db
         self.mq = self.master.mq
         self.data = self.master.data
@@ -54,7 +57,7 @@ class EndpointMixin(interfaces.InterfaceTests):
             if pp == '/':
                 continue
             if not pp.startswith('/') or pp.endswith('/'):
-                raise AssertionError("invalid pattern %r" % (pp,))
+                raise AssertionError(f"invalid pattern {repr(pp)}")
         pathPatterns = [tuple(pp.split('/')[1:])
                         for pp in pathPatterns]
         for pp in pathPatterns:
@@ -81,7 +84,7 @@ class EndpointMixin(interfaces.InterfaceTests):
         self.assertIdentical(endpoint, self.ep)
         rv = yield endpoint.get(resultSpec, kwargs)
 
-        if self.ep.isCollection:
+        if self.ep.kind == base.EndpointKind.COLLECTION:
             self.assertIsInstance(rv, (list, base.ListResult))
         else:
             self.assertIsInstance(rv, (dict, type(None)))
@@ -98,9 +101,14 @@ class EndpointMixin(interfaces.InterfaceTests):
     # interface tests
 
     def test_get_spec(self):
-        @self.assertArgSpecMatches(self.ep.get)
-        def get(self, resultSpec, kwargs):
-            pass
+        try:
+            @self.assertArgSpecMatches(self.ep.get)
+            def get(self, resultSpec, kwargs):
+                pass
+        except trial.unittest.FailTest:
+            @self.assertArgSpecMatches(self.ep.get)
+            def get(self, result_spec, kwargs):
+                pass
 
     def test_control_spec(self):
         @self.assertArgSpecMatches(self.ep.control)
