@@ -27,6 +27,7 @@ from buildbot.process import metrics
 from buildbot.process.properties import Properties
 from buildbot.util import Notifier
 from buildbot.util import bytes2unicode
+from buildbot.util import deferwaiter
 from buildbot.util import service
 
 
@@ -56,6 +57,10 @@ class AbstractWorker(service.BuildbotService):
     # override to True if isCompatibleWithBuild may return False
     builds_may_be_incompatible = False
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._deferwaiter = deferwaiter.DeferWaiter()
+
     def checkConfig(self, name, password, max_builds=None,
                     notify_on_missing=None,
                     missing_timeout=None,
@@ -93,6 +98,7 @@ class AbstractWorker(service.BuildbotService):
 
         self._graceful = False
         self._paused = False
+        self._pause_reason = None
 
         # these are set when the service is started
         self.manager = None
@@ -127,8 +133,7 @@ class AbstractWorker(service.BuildbotService):
         self.notify_on_missing = notify_on_missing
         for i in notify_on_missing:
             if not isinstance(i, str):
-                config.error(
-                    'notify_on_missing arg %r is not a string' % (i,))
+                config.error(f'notify_on_missing arg {repr(i)} is not a string')
 
         self.missing_timeout = missing_timeout
         self.missing_timer = None
@@ -146,7 +151,7 @@ class AbstractWorker(service.BuildbotService):
         self._configured_builderid_list = None
 
     def __repr__(self):
-        return "<{} {}>".format(self.__class__.__name__, repr(self.name))
+        return f"<{self.__class__.__name__} {repr(self.name)}>"
 
     @property
     def workername(self):
@@ -194,9 +199,9 @@ class AbstractWorker(service.BuildbotService):
         my caller should give up the build and try to get another worker
         to look at it.
         """
-        log.msg("acquireLocks(worker {}, locks {})".format(self, self.locks))
+        log.msg(f"acquireLocks(worker {self}, locks {self.locks})")
         if not self.locksAvailable():
-            log.msg("worker {} can't lock, giving up".format(self))
+            log.msg(f"worker {self} can't lock, giving up")
             return False
         # all locks are available, claim them all
         for lock, access in self.locks:
@@ -207,7 +212,7 @@ class AbstractWorker(service.BuildbotService):
         """
         I am called to release any locks after a build has finished
         """
-        log.msg("releaseLocks({}): {}".format(self, self.locks))
+        log.msg(f"releaseLocks({self}): {self.locks}")
         for lock, access in self.locks:
             lock.release(self, access)
 
@@ -318,8 +323,7 @@ class AbstractWorker(service.BuildbotService):
                 self.properties.setProperty("machine_name", self.machine_name,
                                             "Worker")
             else:
-                log.err("Unknown machine '{}' for worker '{}'".format(
-                    self.machine_name, self.name))
+                log.err(f"Unknown machine '{self.machine_name}' for worker '{self.name}'")
 
         # update our records with the worker manager
         if not self.registration:
@@ -366,6 +370,7 @@ class AbstractWorker(service.BuildbotService):
         yield self.disconnect()
         yield self.waitForCompleteShutdown()
 
+        yield self._deferwaiter.wait()
         yield super().stopService()
 
     def isCompatibleWithBuild(self, build_props):
@@ -417,7 +422,10 @@ class AbstractWorker(service.BuildbotService):
     def attached(self, conn):
         """This is called when the worker connects."""
 
-        assert self.conn is None
+        if self.conn is not None:
+            raise AssertionError(
+                f"{self.name}: {conn.get_peer()} connecting, "
+                f"but we are already connected to: {self.conn.get_peer()}")
 
         metrics.MetricCountEvent.log("AbstractWorker.attached_workers", 1)
 
@@ -464,7 +472,8 @@ class AbstractWorker(service.BuildbotService):
         self.stopMissingTimer()
         yield self.updateWorker()
         yield self.botmaster.maybeStartBuildsForWorker(self.name)
-        self.updateState()
+        self._update_paused()
+        self._update_graceful()
 
     def messageReceivedFromWorker(self):
         now = time.time()
@@ -498,7 +507,7 @@ class AbstractWorker(service.BuildbotService):
         metrics.MetricCountEvent.log("AbstractWorker.attached_workers", -1)
 
         self._old_builder_list = []
-        log.msg("Worker.detached({})".format(self.name))
+        log.msg(f"Worker.detached({self.name})")
         self.releaseLocks()
         yield self.master.data.updates.workerDisconnected(
             workerid=self.workerid,
@@ -522,7 +531,7 @@ class AbstractWorker(service.BuildbotService):
         """
         if self.conn is None:
             return defer.succeed(None)
-        log.msg("disconnecting old worker {} now".format(self.name))
+        log.msg(f"disconnecting old worker {self.name} now")
         # When this Deferred fires, we'll be ready to accept the new worker
         return self._disconnect(self.conn)
 
@@ -578,11 +587,11 @@ class AbstractWorker(service.BuildbotService):
         return builder.attached(self, self.worker_commands)
 
     def controlWorker(self, key, params):
-        log.msg("worker {} wants to {}: {}".format(self.name, key[-1], params))
+        log.msg(f"worker {self.name} wants to {key[-1]}: {params}")
         if key[-1] == "stop":
             return self.shutdownRequested()
         if key[-1] == "pause":
-            self.pause()
+            self.pause(params.get("reason", None))
         if key[-1] == "unpause":
             self.unpause()
         if key[-1] == "kill":
@@ -592,7 +601,7 @@ class AbstractWorker(service.BuildbotService):
     def shutdownRequested(self):
         self._graceful = True
         self.maybeShutdown()
-        self.updateState()
+        self._update_graceful()
 
     def addWorkerForBuilder(self, wfb):
         self.workerforbuilders[wfb.builder_name] = wfb
@@ -603,6 +612,9 @@ class AbstractWorker(service.BuildbotService):
         except KeyError:
             pass
 
+    def buildStarted(self, wfb):
+        pass
+
     def buildFinished(self, wfb):
         """This is called when a build on this worker is finished."""
         self.botmaster.maybeStartBuildsForWorker(self.name)
@@ -657,20 +669,33 @@ class AbstractWorker(service.BuildbotService):
         d = self.shutdown()
         d.addErrback(log.err, 'error while shutting down worker')
 
-    def updateState(self):
-        self.master.data.updates.setWorkerState(self.workerid, self._paused, self._graceful)
+    def _update_paused(self):
+        self._deferwaiter.add(
+            self.master.data.updates.set_worker_paused(
+                self.workerid,
+                self._paused,
+                self._pause_reason
+            )
+        )
 
-    def pause(self):
+    def _update_graceful(self):
+        self._deferwaiter.add(
+            self.master.data.updates.set_worker_graceful(self.workerid, self._graceful)
+        )
+
+    def pause(self, reason):
         """Stop running new builds on the worker."""
         self._paused = True
-        self.updateState()
+        self._pause_reason = reason
+        self._update_paused()
 
     def unpause(self):
         """Restart running new builds on the worker."""
         self._paused = False
+        self._pause_reason = None
         self.stopQuarantineTimer()
         self.botmaster.maybeStartBuildsForWorker(self.name)
-        self.updateState()
+        self._update_paused()
 
     def isPaused(self):
         return self._paused
@@ -684,8 +709,7 @@ class AbstractWorker(service.BuildbotService):
 
         self.quarantine_timer = self.master.reactor.callLater(
             self.quarantine_timeout, self.exitQuarantine)
-        log.msg("{} has been put in quarantine for {}s".format(
-            self.name, self.quarantine_timeout))
+        log.msg(f"{self.name} has been put in quarantine for {self.quarantine_timeout}s")
         # next we will wait twice as long
         self.quarantine_timeout *= 2
         if self.quarantine_timeout > self.quarantine_max_timeout:
@@ -693,7 +717,7 @@ class AbstractWorker(service.BuildbotService):
             self.quarantine_timeout = self.quarantine_max_timeout
 
     def exitQuarantine(self):
-        log.msg("{} has left quarantine".format(self.name))
+        log.msg(f"{self.name} has left quarantine")
         self.quarantine_timer = None
         self.botmaster.maybeStartBuildsForWorker(self.name)
 
@@ -712,11 +736,11 @@ class Worker(AbstractWorker):
         self.startMissingTimer()
 
     @defer.inlineCallbacks
-    def attached(self, bot):
+    def attached(self, conn):
         try:
-            yield super().attached(bot)
+            yield super().attached(conn)
         except Exception as e:
-            log.err(e, "worker {} cannot attach".format(self.name))
+            log.err(e, f"worker {self.name} cannot attach")
             return
 
     def buildFinished(self, wfb):
