@@ -19,26 +19,33 @@ from twisted.python import log
 
 from buildbot.process.measured_service import MeasuredBuildbotServiceManager
 from buildbot.util import misc
+from buildbot.worker.protocols import msgpack as bbmsgpack
 from buildbot.worker.protocols import pb as bbpb
 
 
 class WorkerRegistration:
 
-    __slots__ = ['master', 'worker', 'pbReg']
+    __slots__ = ['master', 'worker', 'pbReg', 'msgpack_reg']
 
     def __init__(self, master, worker):
         self.master = master
         self.worker = worker
+        self.pbReg = None
+        self.msgpack_reg = None
 
     def __repr__(self):
-        return "<{} for {}>".format(self.__class__.__name__, repr(self.worker.workername))
+        return f"<{self.__class__.__name__} for {repr(self.worker.workername)}>"
 
     @defer.inlineCallbacks
     def unregister(self):
         bs = self.worker
         # update with portStr=None to remove any registration in place
-        yield self.master.workers.pb.updateRegistration(
-            bs.workername, bs.password, None)
+        if self.pbReg is not None:
+            yield self.master.workers.pb.updateRegistration(
+                bs.workername, bs.password, None)
+        if self.msgpack_reg is not None:
+            yield self.master.workers.msgpack.updateRegistration(
+                bs.workername, bs.password, None)
         yield self.master.workers._unregister(self)
 
     @defer.inlineCallbacks
@@ -50,9 +57,17 @@ class WorkerRegistration:
                 worker_config.workername, worker_config.password,
                 global_config.protocols['pb']['port'])
 
+        if 'msgpack_experimental_v7' in global_config.protocols:
+            self.msgpack_reg = yield self.master.workers.msgpack.updateRegistration(
+                worker_config.workername, worker_config.password,
+                global_config.protocols['msgpack_experimental_v7']['port'])
+
     def getPBPort(self):
         return self.pbReg.getPort()
 
+    def get_msgpack_port(self):
+        return self.msgpack_reg.getPort()
+
 
 class WorkerManager(MeasuredBuildbotServiceManager):
 
@@ -67,6 +82,7 @@ class WorkerManager(MeasuredBuildbotServiceManager):
         super().__init__()
 
         self.pb = bbpb.Listener(master)
+        self.msgpack = bbmsgpack.Listener(master)
 
         # WorkerRegistration instances keyed by worker name
         self.registrations = {}
@@ -101,8 +117,8 @@ class WorkerManager(MeasuredBuildbotServiceManager):
     @defer.inlineCallbacks
     def newConnection(self, conn, workerName):
         if workerName in self.connections:
-            log.msg(("Got duplication connection from '{}'"
-                     " starting arbitration procedure").format(workerName))
+            log.msg(f"Got duplication connection from '{workerName}'"
+                    " starting arbitration procedure")
             old_conn = self.connections[workerName]
             try:
                 yield misc.cancelAfter(self.PING_TIMEOUT,
@@ -113,22 +129,21 @@ class WorkerManager(MeasuredBuildbotServiceManager):
                 raise RuntimeError("rejecting duplicate worker")
             except defer.CancelledError:
                 old_conn.loseConnection()
-                log.msg("Connected worker '{}' ping timed out after {} seconds".format(workerName,
-                        self.PING_TIMEOUT))
+                log.msg(f"Connected worker '{workerName}' ping timed out after {self.PING_TIMEOUT} "
+                        "seconds")
             except RuntimeError:
                 raise
             except Exception as e:
                 old_conn.loseConnection()
-                log.msg("Got error while trying to ping connected worker {}:{}".format(workerName,
-                                                                                       e))
-            log.msg("Old connection for '{}' was lost, accepting new".format(workerName))
+                log.msg(f"Got error while trying to ping connected worker {workerName}:{e}")
+            log.msg(f"Old connection for '{workerName}' was lost, accepting new")
 
         try:
             yield conn.remotePrint(message="attached")
             info = yield conn.remoteGetWorkerInfo()
-            log.msg("Got workerinfo from '{}'".format(workerName))
+            log.msg(f"Got workerinfo from '{workerName}'")
         except Exception as e:
-            log.msg("Failed to communicate with worker '{}'\n{}".format(workerName, e))
+            log.msg(f"Failed to communicate with worker '{workerName}'\n{e}".format(workerName, e))
             raise
 
         conn.info = info
