@@ -24,7 +24,7 @@ import json
 from buildbot.util import bytes2unicode
 
 
-class BaseHookHandler(object):
+class BaseHookHandler:
     def __init__(self, master, options):
         self.master = master
         self.options = options
@@ -45,7 +45,7 @@ class BaseHookHandler(object):
 
             Make sure to properly decode bytes to unicode strings.
             """
-            if (isinstance(value, type([]))):
+            if isinstance(value, type([])):
                 value = value[0]
             return bytes2unicode(value)
 
@@ -72,6 +72,7 @@ class BaseHookHandler(object):
         author = firstOrNothing(args.get(b'author'))
         if not author:
             author = firstOrNothing(args.get(b'who'))
+        committer = firstOrNothing(args.get(b'committer'))
         comments = firstOrNothing(args.get(b'comments'))
         branch = firstOrNothing(args.get(b'branch'))
         category = firstOrNothing(args.get(b'category'))
@@ -80,11 +81,21 @@ class BaseHookHandler(object):
         project = firstOrNothing(args.get(b'project')) or ''
         codebase = firstOrNothing(args.get(b'codebase'))
 
-        chdict = dict(author=author, files=files, comments=comments,
-                      revision=revision, when_timestamp=when,
-                      branch=branch, category=category, revlink=revlink,
-                      properties=properties, repository=repository,
-                      project=project, codebase=codebase)
+        chdict = {
+            "author": author,
+            "committer": committer,
+            "files": files,
+            "comments": comments,
+            "revision": revision,
+            "when_timestamp": when,
+            "branch": branch,
+            "category": category,
+            "revlink": revlink,
+            "properties": properties,
+            "repository": repository,
+            "project": project,
+            "codebase": codebase
+        }
         return ([chdict], None)
 
 
