@@ -53,7 +53,8 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                  groupName=None,
                  avatarPattern=None,
                  avatarData=None,
-                 accountExtraFields=None):
+                 accountExtraFields=None,
+                 tls=None):
         # Throw import error now that this is being used
         if not ldap3:
             importlib.import_module('ldap3')
@@ -81,13 +82,14 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
             accountExtraFields = []
         self.accountExtraFields = accountExtraFields
         self.ldap_encoding = ldap3.get_config_parameter('DEFAULT_SERVER_ENCODING')
+        self.tls = tls
 
     def connectLdap(self):
         server = urlparse(self.uri)
         netloc = server.netloc.split(":")
         # define the server and the connection
         s = ldap3.Server(netloc[0], port=int(netloc[1]), use_ssl=server.scheme == 'ldaps',
-                         get_info=ldap3.ALL)
+                         get_info=ldap3.ALL, tls=self.tls)
 
         auth = ldap3.SIMPLE
         if self.bindUser is None and self.bindPw is None:
@@ -108,7 +110,7 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
         def thd():
             c = self.connectLdap()
             infos = {'username': username}
-            pattern = self.accountPattern % dict(username=username)
+            pattern = self.accountPattern % {"username": username}
             res = self.search(c, self.accountBase, pattern,
                               attributes=[
                                   self.accountEmail, self.accountFullName] +
@@ -133,7 +135,7 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                 return infos
 
             # needs double quoting of backslashing
-            pattern = self.groupMemberPattern % dict(dn=ldap3.utils.conv.escape_filter_chars(dn))
+            pattern = self.groupMemberPattern % {"dn": ldap3.utils.conv.escape_filter_chars(dn)}
             res = self.search(c, self.groupBase, pattern,
                               attributes=[self.groupName])
             infos['groups'] = flatten([group_infos['attributes'][self.groupName]
@@ -162,9 +164,9 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
         def thd():
             c = self.connectLdap()
             if username:
-                pattern = self.accountPattern % dict(username=username)
+                pattern = self.accountPattern % {"username": username}
             elif email:
-                pattern = self.avatarPattern % dict(email=email)
+                pattern = self.avatarPattern % {"email": email}
             else:
                 return None
             res = self.search(c, self.accountBase, pattern,
