@@ -26,6 +26,7 @@ from twisted.python import log
 from twisted.web.error import Error
 
 from buildbot.data import exceptions
+from buildbot.data.base import EndpointKind
 from buildbot.util import bytes2unicode
 from buildbot.util import toJson
 from buildbot.util import unicode2bytes
@@ -46,7 +47,7 @@ class ContentTypeParser:
         self.typeheader = contenttype
 
     def gettype(self):
-        mimetype, options = cgi.parse_header(
+        mimetype, _ = cgi.parse_header(
             bytes2unicode(self.typeheader))
         return mimetype
 
@@ -72,7 +73,7 @@ class RestRootResource(resource.Resource):
             if version < min_vers:
                 continue
             child = klass(master)
-            child_path = 'v{}'.format(version)
+            child_path = f'v{version}'
             child_path = unicode2bytes(child_path)
             self.putChild(child_path, child)
             if version == latest:
@@ -81,18 +82,20 @@ class RestRootResource(resource.Resource):
     def render(self, request):
         request.setHeader(b"content-type", JSON_ENCODED)
         min_vers = self.master.config.www.get('rest_minimum_version', 0)
-        api_versions = dict(('v{}'.format(v), '{}api/v{}'.format(self.base_url, v))
+        api_versions = dict((f'v{v}', f'{self.base_url}api/v{v}')
                             for v in self.version_classes
                             if v > min_vers)
-        data = json.dumps(dict(api_versions=api_versions))
+        data = json.dumps({"api_versions": api_versions})
         return unicode2bytes(data)
 
 
-JSONRPC_CODES = dict(parse_error=-32700,
-                     invalid_request=-32600,
-                     method_not_found=-32601,
-                     invalid_params=-32602,
-                     internal_error=-32603)
+JSONRPC_CODES = {
+    "parse_error": -32700,
+    "invalid_request": -32600,
+    "method_not_found": -32601,
+    "invalid_params": -32602,
+    "internal_error": -32603
+}
 
 
 class V2RootResource(resource.Resource):
@@ -174,8 +177,7 @@ class V2RootResource(resource.Resource):
         try:
             data = json.loads(bytes2unicode(request.content.read()))
         except Exception as e:
-            raise BadJsonRpc2("JSON parse error: {}".format(
-                str(e)), JSONRPC_CODES["parse_error"]) from e
+            raise BadJsonRpc2(f"JSON parse error: {str(e)}", JSONRPC_CODES["parse_error"]) from e
 
         if isinstance(data, list):
             raise BadJsonRpc2("JSONRPC batch requests are not supported",
@@ -186,10 +188,9 @@ class V2RootResource(resource.Resource):
 
         def check(name, types, typename):
             if name not in data:
-                raise BadJsonRpc2("missing key '{}'".format(name), JSONRPC_CODES["invalid_request"])
+                raise BadJsonRpc2(f"missing key '{name}'", JSONRPC_CODES["invalid_request"])
             if not isinstance(data[name], types):
-                raise BadJsonRpc2("'{}' must be {}".format(name, typename),
-                                  JSONRPC_CODES["invalid_request"])
+                raise BadJsonRpc2(f"'{name}' must be {typename}", JSONRPC_CODES["invalid_request"])
         check("jsonrpc", (str,), "a string")
         check("method", (str,), "a string")
         check("id", (str, int, type(None)),
@@ -209,11 +210,11 @@ class V2RootResource(resource.Resource):
             if isinstance(msg, bytes):
                 msg = bytes2unicode(msg)
             if self.debug:
-                log.msg("JSONRPC error: {}".format(msg))
+                log.msg(f"JSONRPC error: {msg}")
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', JSON_ENCODED)
             if "error" not in jsonRpcReply:  # already filled in by caller
-                jsonRpcReply['error'] = dict(code=jsonrpccode, message=msg)
+                jsonRpcReply['error'] = {"code": jsonrpccode, "message": msg}
             data = json.dumps(jsonRpcReply)
             data = unicode2bytes(data)
             request.write(data)
@@ -249,13 +250,18 @@ class V2RootResource(resource.Resource):
     def decodeResultSpec(self, request, endpoint):
         args = request.args
         entityType = endpoint.rtype.entityType
-        return self.master.data.resultspec_from_jsonapi(args, entityType, endpoint.isCollection)
+        return self.master.data.resultspec_from_jsonapi(
+            args,
+            entityType,
+            endpoint.kind == EndpointKind.COLLECTION
+        )
 
-    def encodeRaw(self, data, request):
+    def encodeRaw(self, data, request, is_inline):
         request.setHeader(b"content-type",
                           unicode2bytes(data['mime-type']) + b'; charset=utf-8')
-        request.setHeader(b"content-disposition",
-                          b'attachment; filename=' + unicode2bytes(data['filename']))
+        if not is_inline:
+            request.setHeader(b"content-disposition",
+                              b'attachment; filename=' + unicode2bytes(data['filename']))
         request.write(unicode2bytes(data['raw']))
         return
 
@@ -263,11 +269,11 @@ class V2RootResource(resource.Resource):
     def renderRest(self, request):
         def writeError(msg, errcode=404, jsonrpccode=None):
             if self.debug:
-                log.msg("REST error: {}".format(msg))
+                log.msg(f"REST error: {msg}")
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', b'text/plain; charset=utf-8')
             msg = bytes2unicode(msg)
-            data = json.dumps(dict(error=msg))
+            data = json.dumps({"error": msg})
             data = unicode2bytes(data)
             request.write(data)
 
@@ -277,15 +283,18 @@ class V2RootResource(resource.Resource):
             rspec = self.decodeResultSpec(request, ep)
             data = yield ep.get(rspec, kwargs)
             if data is None:
-                msg = ("not found while getting from {} with "
-                       "arguments {} and {}").format(repr(ep), repr(rspec),
-                                                     str(kwargs))
+                msg = (f"not found while getting from {repr(ep)} with "
+                       f"arguments {repr(rspec)} and {str(kwargs)}")
                 msg = unicode2bytes(msg)
                 writeError(msg, errcode=404)
                 return
 
-            if ep.isRaw:
-                self.encodeRaw(data, request)
+            if ep.kind == EndpointKind.RAW:
+                self.encodeRaw(data, request, False)
+                return
+
+            if ep.kind == EndpointKind.RAW_INLINE:
+                self.encodeRaw(data, request, True)
                 return
 
             # post-process any remaining parts of the resultspec
@@ -293,7 +302,7 @@ class V2RootResource(resource.Resource):
 
             # annotate the result with some metadata
             meta = {}
-            if ep.isCollection:
+            if ep.kind == EndpointKind.COLLECTION:
                 offset, total = data.offset, data.total
                 if offset is None:
                     offset = 0
@@ -328,7 +337,7 @@ class V2RootResource(resource.Resource):
 
             # set up caching
             if self.cache_seconds:
-                now = datetime.datetime.utcnow()
+                now = datetime.datetime.now(datetime.timezone.utc)
                 expires = now + datetime.timedelta(seconds=self.cache_seconds)
                 expiresBytes = unicode2bytes(
                     expires.strftime("%a, %d %b %Y %H:%M:%S GMT"))
@@ -368,16 +377,16 @@ class V2RootResource(resource.Resource):
         def writeError(msg, errcode=400):
             msg = bytes2unicode(msg)
             if self.debug:
-                log.msg("HTTP error: {}".format(msg))
+                log.msg(f"HTTP error: {msg}")
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', b'text/plain; charset=utf-8')
             if request.method == b'POST':
                 # jsonRPC callers want the error message in error.message
-                data = json.dumps(dict(error=dict(message=msg)))
+                data = json.dumps({"error": {"message": msg}})
                 data = unicode2bytes(data)
                 request.write(data)
             else:
-                data = json.dumps(dict(error=msg))
+                data = json.dumps({"error": msg})
                 data = unicode2bytes(data)
                 request.write(data)
             request.finish()
