@@ -3,6 +3,8 @@
 // inspired by this methodology
 // http://www.lindstromhenrik.com/using-protractor-with.jsscript/
 
+import { bbrowser } from '../utils';
+
 export const testPageUrl = 'http://localhost:8011'
 
 export class BasePage {
@@ -10,14 +12,14 @@ export class BasePage {
     constructor() {}
 
     async logOut() {
-        await element(By.css('.avatar img')).click();
+        await element(By.css('.navbar-right a.dropdown-toggle')).click();
         await element(By.linkText('Logout')).click();
         const anonymousButton = element.all(By.css('.dropdown')).first();
         expect(await anonymousButton.getText()).toContain("Anonymous");
     }
 
     async loginUser(user, password) {
-        await browser.get(`http://${user}:${password}@localhost:8011/auth/login`);
+        await bbrowser.get(`http://${user}:${password}@localhost:8011/auth/login`);
         const anonymousButton = element.all(By.css('.dropdown')).first();
         expect(await anonymousButton.getText()).not.toContain("Anonymous");
     }
