@@ -3,6 +3,7 @@
 
 import { BasePage } from "./base";
 import { browser, by, element, ExpectedConditions as EC } from 'protractor';
+import { bbrowser } from '../utils';
 
 export class DashboardPage extends BasePage {
     constructor() {
@@ -10,14 +11,12 @@ export class DashboardPage extends BasePage {
     }
 
     async go() {
-        await browser.get('#/mydashboard');
-        await browser.wait(EC.urlContains('#/mydashboard'),
-                           10000,
-                           "URL does not contain #/mydashboard");
+        await bbrowser.get('#/mydashboard');
+        await bbrowser.wait(EC.urlContains('#/mydashboard'),
+                            "URL does not contain #/mydashboard");
         var buildLink = element.all(By.linkText("runtests/1")).first();
-        await browser.wait(EC.elementToBeClickable(buildLink),
-                           500000,
-                           "runtests/1 link not clickable");
+        await bbrowser.wait(EC.elementToBeClickable(buildLink),
+                            "runtests/1 link not clickable");
         await buildLink.click();
     }
 }
