@@ -24,6 +24,7 @@ from __future__ import print_function
 import datetime
 import os
 import re
+import sys
 from subprocess import PIPE
 from subprocess import STDOUT
 from subprocess import Popen
@@ -59,11 +60,15 @@ def mTimeVersion(init_file):
     for root, _, files in os.walk(cwd):
         for f in files:
             m = max(os.path.getmtime(os.path.join(root, f)), m)
-    d = datetime.datetime.utcfromtimestamp(m)
+
+    if sys.version_info >= (3, 3):
+        d = datetime.datetime.fromtimestamp(m, datetime.timezone.utc)
+    else:
+        d = datetime.datetime.utcfromtimestamp(m)
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='1670154335  (HEAD -> master, tag: v3.7.0)'):
+def getVersionFromArchiveId(git_archive_id='1703611808  (tag: v3.10.1, 3.10.x)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
@@ -86,7 +91,10 @@ def getVersionFromArchiveId(git_archive_id='1670154335  (HEAD -> master, tag: v3
 
         # archived revision is not tagged, use the commit date
         tstamp = git_archive_id.strip().split()[0]
-        d = datetime.datetime.utcfromtimestamp(int(tstamp))
+        if sys.version_info >= (3, 3):
+            d = datetime.datetime.fromtimestamp(int(tstamp), datetime.timezone.utc)
+        else:
+            d = datetime.datetime.utcfromtimestamp(int(tstamp))
         return d.strftime('%Y.%m.%d')
     return None
 
